@@ -16,9 +16,9 @@ colorme() {
 
 export SHELLPROCESS=$(grep Name: /proc/$PPID/status | cut -f2)
 
-if [ ! -e /init -a $SHELLPROCESS != "telnetd"  ]
+# Only apply the colored prompt for SSH connections
+if [ ! -e /init -a $SHELLPROCESS == "sshd"  ]
 then
-    # We are not on pmulti nor telnet, enable color
     colorme
 fi
 
