@@ -49,6 +49,8 @@ class SMTOtuMode
     const OTU8000_ONMSI_LOGO     = "Otu8000Onmsi.png";
     const OTH_ONMSI_LOGO         = "AFTHOnmsi.png";
     const OTH_ROTAU_LOGO         = "AFTHRotau.png";
+    const FTH7K_ONMSI_LOGO       = "FTH7000Onmsi.png";
+    const FTH7K_ROTAU_LOGO       = "FTH7000Rotau.png";
     const OTU8000_ROTAU_LOGO     = "Otu8000Rotau.png";
     const RESCUE_LOGO    = "Rescue133x38.png";
     const SMART_OTU_DISPLAY = "SmartOTU";
@@ -193,7 +195,7 @@ class SMTOtuMode
         }
         else if ( self::isONMSi() )
         {
-            return SMTOtuType::isCOtu_EOTDRV2()? self::OTU5000_ONMSI_LOGO : (SMTOtuType::isOTH()? self::OTH_ONMSI_LOGO : self::OTU8000_ONMSI_LOGO);
+            return SMTOtuType::isCOtu_EOTDRV2()? self::OTU5000_ONMSI_LOGO : (SMTOtuType::isOTH()? self::OTH_ONMSI_LOGO : (SMTOtuType::isFTH7K()? self::FTH7K_ONMSI_LOGO : self::OTU8000_ONMSI_LOGO));
         }
         else if ( self::isONMS() )
         {
@@ -205,7 +207,7 @@ class SMTOtuMode
         }
         else if ( self::isROTAU() )
         {
-            return SMTOtuType::isCOtu_EOTDRV2()? self::OTU5000_ROTAU_LOGO: (SMTOtuType::isOTH()? self::OTH_ROTAU_LOGO  : self::OTU8000_ROTAU_LOGO);
+            return SMTOtuType::isCOtu_EOTDRV2()? self::OTU5000_ROTAU_LOGO: (SMTOtuType::isOTH()? self::OTH_ROTAU_LOGO  : (SMTOtuType::isFTH7K()? self::FTH7K_ROTAU_LOGO : self::OTU8000_ROTAU_LOGO) );
         }
         else if ( self::isRESCUE() )
         {
