@@ -182,7 +182,7 @@ class SMTOtuMonitoringOptions
    		}
    		
    		// Replace default HIGHSENS mode by LEGACY
-   		if ( !SMTOtuType::isOTH() ) //no legacy mode on OTH
+   		if ( !SMTOtuType::isOTH() && !SMTOtuType::isFTH7K() ) //no legacy mode on OTH
    		{
     		try
     		{
