@@ -31,17 +31,17 @@ class SMTOtuType
     const OTU8KV2  = 'Otu8kv2';
     const OTU8KV2e = 'Otu8kv2e';
     const EOTDRV2  = 'Eotdrv2';
-    const MTS8KV2  = 'Mts8kv2';
     const OLD_OTH  = 'A-FTH';
     const OTH      = 'FTH-9000';
+    const FTH7K    = 'FTH-7000';
     
-    const DEFAULT_OTU_TYPE = self::OTU8KV2;
+    const DEFAULT_OTU_TYPE = self::COTU; // OTU8kv2/OTU8kv2e no longer supported
     
     const COTU_DISPLAY    = 'OTU 5000';
     const OTU8KV2_DISPLAY = 'OTU 8000v2';
     const EOTDRV2_DISPLAY = 'EOTDR';
-    const MTS8KV2_DISPLAY = 'MTS 8000v2';
     const OTH_DISPLAY     = 'FTH-9000';
+    const FTH7K_DISPLAY   = 'FTH-7000';
     
     
     /**
@@ -52,7 +52,7 @@ class SMTOtuType
      */
     public static function getSupportedTypes()
     {
-        return array(self::OTU8KV2, self::OTU8KV2e, self::COTU, self::EOTDRV2, self::MTS8KV2, self::OTH );
+        return array(self::OTU8KV2, self::OTU8KV2e, self::COTU, self::EOTDRV2, self::OTH, self::FTH7K );
     }    
     
     /**
@@ -90,15 +90,6 @@ class SMTOtuType
     {
     	return self::isEOTDRV2() || self::isCOtu();
     }
-    
-    /**
-     * Whether the OTU type is MTS8KV2
-     * @return boolean Whether the OTU type is MTS8KV2
-     */
-    public static function isMTS8KV2()
-    {
-    	return ( strcasecmp( self::getOtuType() , self::MTS8KV2 ) == 0 );
-    } 
 
     /**
      * Whether the OTU type is isOTH
@@ -106,7 +97,16 @@ class SMTOtuType
      */
     public static function isOTH()
     {
-        return ( (strcasecmp( self::getOtuType() , self::OTH ) == 0) || (strcasecmp( self::getOtuType() , self::OLD_OTH ) == 0) );
+        return ( (strcasecmp( self::getOtuType() , self::OTH ) == 0) );
+    }
+    
+    /**
+     * Whether the OTU type is FTH-7000
+     * @return boolean Whether the OTU type is FTH-7000
+     */
+    public static function isFTH7K()
+    {
+        return ( strcasecmp( self::getOtuType() , self::FTH7K ) == 0);
     }
     
     /**
@@ -121,29 +121,14 @@ class SMTOtuType
   	         (strcasecmp( $type , self::OTU8KV2 ) == 0)  ||
     	     (strcasecmp( $type , self::OTU8KV2e ) == 0) ||
 	         (strcasecmp( $type , self::EOTDRV2 ) == 0)  ||
-	         (strcasecmp( $type , self::MTS8KV2 ) == 0)  ||
-    	     (strcasecmp( $type , self::OTH ) == 0)
+    	     (strcasecmp( $type , self::OTH ) == 0)      ||
+    	     (strcasecmp( $type , self::FTH7K ) == 0)
     	   )
     	{
     		return true;
     	}
     	return false;
     }
-        
-    /**
-     * Whether the string value is an existing OTU type
-     *
-     * @param string $type
-     * @return boolean
-     */
-    public static function isOld_OTH( $type )
-    {
-        if ( strcasecmp( $type , self::OLD_OTH ) == 0 )
-        {
-            return true;
-        }
-        return false;
-    }
     
     /**
      * The OTU type display name
@@ -164,14 +149,14 @@ class SMTOtuType
     	{
     		return self::EOTDRV2_DISPLAY;
     	}
-    	else if ( self::isMTS8KV2() )
-    	{
-    		return self::MTS8KV2_DISPLAY;
-    	}
     	else if ( self::isOTH() )
     	{
     	    return self::OTH_DISPLAY;
     	}
+    	else if ( self::isFTH7K() )
+    	{
+    	    return self::FTH7K_DISPLAY;
+    	}
     	else
     	{
     	    return "";
@@ -203,11 +188,7 @@ class SMTOtuType
         if ( !isset($_SESSION[self::OTU_TYPE] ) || $_SESSION[self::OTU_TYPE] == NULL )
         { 
             $type = self::retrieveOtuType();
-            if ( self::isOld_OTH($type) )
-            {   
-                self::setOtuType( self::OTH );
-            }
-            else if ( self::isValid( $type ) )
+            if ( self::isValid( $type ) )
                 {
                 self::setOtuType( $type );
                 }
@@ -251,7 +232,7 @@ class SMTOtuType
 //         	fclose( $templogFileHandle );
 //         }
         
-        return self::isOld_OTH($type)? self::OTH : (self::isValid($type)? $type : self::DEFAULT_OTU_TYPE);
+        return (self::isValid($type)? $type : self::DEFAULT_OTU_TYPE);
     }
     
 }
