@@ -24,15 +24,14 @@ use app\parser\SMTOtuApi;
 
 
 class SMTUserUtil
-{   
-    const INSTALL_ETH_PASSWD_SHA_256 = "bf8000ed022ff815da9fa6733840fbe70be3b338bc5a1ae2154a59cc4d128925";
+{
     const SYS_USER = "cm9vdA==";
     const INSTALL_IP_USER = "aW5zdGFsbGV0aA==";
     const DEFAULT_INSTALL_USER = "YWRtaW4=";
-    const DEFAULT_INSTALL_PASSWORD_SHA_256 = "5e884898da28047151d0e56f8dc6292773603d0d6aabbdd62a11ef721d1542d8";
-    const PASSWD = "/otu/smartOTU/.passwd";
+    const OLD_PASSWD_FILE = "/otu/smartOTU/.passwd";
     const USER_ALIASES_FILE = "/etc/aliases";
     const SMARTOTU_USER = "smartotu";
+    const SMARTOTU_GUEST_USER = "smartotuguest";
     
     /**
      * Authenticate the user from a password file and save it in the context
@@ -65,12 +64,12 @@ class SMTUserUtil
     	    $user = SMTUserDto::forgeUser( $login, $userRoleName );
         }
         
-        $context->setUser($user);
-        
         if ( $user == NULL )
         {
         	throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_BAD_LOGIN );
         }
+        
+        $context->setUser($user);
     	
     	return $user;
     }
@@ -82,7 +81,7 @@ class SMTUserUtil
      */
     private static function readOldPasswordFile()
     {
-        $lines = file(self::PASSWD);
+        $lines = file(self::OLD_PASSWD_FILE);
         return $lines;
     }
     
@@ -120,17 +119,34 @@ class SMTUserUtil
 		}
 		
 		//trac #2922 installeth user, allowed when high security is disabled
-		else if ( ($highSecurityMode == FALSE) && (self::INSTALL_ETH_PASSWD_SHA_256 === $password_sha_256) && 
-		          (strcmp( base64_encode( $login ), self::INSTALL_IP_USER ) == 0)  )
+		else if ( ($highSecurityMode == FALSE) && (strcmp( base64_encode( $login ), self::INSTALL_IP_USER ) == 0) )
 		{
-			$userRole = SMTRoleDto::DEBUG;
-			SMTLogger::getInstance()->trace("checkLogin >> Login Install eth", SMTLogger::PINFO );
-			
-			//with installeth user, always use normal user read from SmartOTU password file (we can change normal user login/password even if we have lost them)
-			$login = self::isOldPasswordFile()? self::getOldInstallUserFromFile() : self::getSmartOtuUnixLogin();
-			SMTLogger::getInstance()->trace("checkLogin >> Installeth user login with User: $login; Role: $userRole", SMTLogger::PINFO );
+			if ( self::checkUserPassword( $login, $password_sha_256) )
+			{
+				$userRole = SMTRoleDto::DEBUG;
+				SMTLogger::getInstance()->trace("checkLogin >> Login Install eth", SMTLogger::PINFO );
+				
+				//with installeth user, always use normal user read from SmartOTU password file (we can change normal user login/password even if we have lost them)
+				$login = self::isOldPasswordFile()? self::getOldInstallUserFromFile() : self::getSmartOtuUnixLogin();
+				SMTLogger::getInstance()->trace("checkLogin >> Installeth user login with User: $login; Role: $userRole", SMTLogger::PINFO );
+			}
+		}
+		// SmartOTU guest unix user disabled with ROOT_ACCESS license (from file system : user removed)
+		else if ( (self::isRootAccessSecurityOption( $context ) == FALSE) && self::checkSmartOtuGuestUnixLogin($login) )
+		{
+			//check guest user password
+			if ( self::checkUserPassword(self::SMARTOTU_GUEST_USER, $password) )
+			{
+				$userRole = SMTRoleDto::USER;
+				SMTLogger::getInstance()->trace("checkLogin >> Login guest User: $login Role: $userRole", SMTLogger::PINFO);
+			}
+			// invalid password given
+			else
+			{
+				SMTLogger::getInstance()->trace("checkLogin >> Invalid password for guest user: $login Role: $userRole", SMTLogger::ERROR);
+				$userRole = NULL;
+			}
 		}
-		
 		//normal user login
 		else
 		{
@@ -142,9 +158,9 @@ class SMTUserUtil
 		    	if ($success)
 		    	{
 		    		//truncate and delete file to avoid a new migration
-		    		$fp = fopen(self::PASSWD, "w");
+		    		$fp = fopen(self::OLD_PASSWD_FILE, "w");
 		    		fclose($fp);
-		    		unlink(self::PASSWD);
+		    		unlink(self::OLD_PASSWD_FILE);
 		    	}
 		    }
 		    
@@ -185,10 +201,10 @@ class SMTUserUtil
 		
 			SMTLogger::getInstance()->trace("checkLogin >> Local mode login with User: $login; Role: $userRole", SMTLogger::PINFO );
 		}
-		//in ONMSi mode or SmartOEM mode, promote user with INSTALL_IP role to change ip settings
+		//in ONMSi mode or SmartOEM mode, promote install user with INSTALL_IP role to change ip settings
 		else if ( ($userRole != NULL) && (SMTOtuMode::isONMSi() || SMTOtuMode::isSmartOem() || SMTOtuMode::isROTAU()))
 		{
-			if ( ($userRole != SMTRoleDto::SUPER_USER) && ($userRole != SMTRoleDto::DEBUG) )
+			if ( ($userRole != SMTRoleDto::SUPER_USER) && ($userRole != SMTRoleDto::DEBUG) && ($userRole != SMTRoleDto::USER) )
 			{
 				$userRole = SMTRoleDto::INSTALL_IP;
 				SMTLogger::getInstance()->trace("checkLogin >> promote User $login with role $userRole", SMTLogger::INFO );
@@ -213,7 +229,7 @@ class SMTUserUtil
 		//la migration n'a pas ete faite
 		if ( self::isOldPasswordFile() )
 		{	
-			$lines = file(self::PASSWD);
+			$lines = file(self::OLD_PASSWD_FILE);
         	foreach ($lines as $line)
         	{
         	    $line = trim($line);
@@ -300,6 +316,10 @@ class SMTUserUtil
     			if ( ($currentRoleDto != NULL) && $currentRoleDto->isEqual( SMTRoleDto::SUPER_USER) && !$highSecurityMode ) //super user => don't check old password or login (we are already logged-in as super user) // super user disabled in enhanced security except in local mode   					   				
     			{
     			    $userFound = TRUE;
+    			    if ( $userFound )
+    			    {
+    			    	$userRole = SMTRoleDto::INSTALL;
+    			    }
     			    SMTLogger::getInstance()->trace("changePassword >> Super user, check user login/password ok for user: $login", SMTLogger::INFO );
     			}
     			// l'utilisateur change ses identifiants, on verifie son login/password actuel
@@ -311,8 +331,23 @@ class SMTUserUtil
     			    {
     			        SMTLogger::getInstance()->trace("changePassword >> Find user login: $login. Check User password", SMTLogger::INFO );
         			    $userFound = self::checkSmartOtuUnixPassword($oldPassword);  // normal user
+        			    if ( $userFound )
+        			    {
+        			    	$userRole = SMTRoleDto::INSTALL;
+        			    }
         			    SMTLogger::getInstance()->trace("changePassword >> Check user old password for user: $login. Result: $userFound", SMTLogger::PINFO );
     			    }
+    			    //smartotu guest user
+    			    else if ( self::checkSmartOtuGuestUnixLogin($login) )
+    			    {
+    			    	SMTLogger::getInstance()->trace("changePassword >> Find guest user login: $login. Check guest User password", SMTLogger::INFO );
+    			    	$userFound = TRUE;//self::checkUserPassword(self::SMARTOTU_GUEST_USER, $oldPassword); // guest user
+//     			    	if ( $userFound )
+//     			    	{
+    			    		$userRole = SMTRoleDto::USER;
+//     			    	}
+    			    	SMTLogger::getInstance()->trace("changePassword >> Check guest user old password for user: $login. Result: $userFound", SMTLogger::PINFO );
+    			    }
     			    else
     			    {
     			        SMTLogger::getInstance()->trace("changePassword >> Failed to find user login: $login. Failed to change User $login password", SMTLogger::ERROR );
@@ -323,37 +358,61 @@ class SMTUserUtil
     			//update password files
     			if ( $userFound  )
     			{
-    				//update linux password for normal user
-    			    $userRole = SMTRoleDto::INSTALL;
-    			    
-				    if ( self::changeSmartOtuUnixLogin($newLogin) === TRUE )
-					{
-						SMTLogger::getInstance()->trace("changePassword >> Successfully changed User $login login to $newLogin", SMTLogger::PINFO );
-					}
-				    else
-				    {
-				    	SMTLogger::getInstance()->trace("Failed to update aliases file. Failed to change User $login to $newLogin", SMTLogger::ERROR );
-				    	throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_FAILED_TO_UPDATE_USER_PASSWORD_FILE );
-				    }
-				    
-					if ( self::changeSmartOtuUnixPassword($newPassword) === TRUE )
-					{
-						SMTLogger::getInstance()->trace("changePassword >> Successfully changed User $login password", SMTLogger::PINFO );
-					}
-					else
-					{
-						SMTLogger::getInstance()->trace("changePassword >> Failed to change password for User $login", SMTLogger::ERROR );
-						throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_FAILED_TO_UPDATE_USER_PASSWORD_FILE );
-					}
+    				if ( self::checkSmartOtuUnixLogin($login) )
+    				{
+	    				//update linux password for normal user
+					    if ( self::changeSmartOtuUnixLogin($newLogin) === TRUE )
+						{
+							SMTLogger::getInstance()->trace("changePassword >> Successfully changed User $login login to $newLogin", SMTLogger::PINFO );
+						}
+					    else
+					    {
+					    	SMTLogger::getInstance()->trace("Failed to update aliases file. Failed to change User $login to $newLogin", SMTLogger::ERROR );
+					    	throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_FAILED_TO_UPDATE_USER_PASSWORD_FILE );
+					    }
+					    sleep(1); //#EPT9328
+						if ( self::changeSmartOtuUnixPassword($newPassword) === TRUE )
+						{
+							SMTLogger::getInstance()->trace("changePassword >> Successfully changed User $login password", SMTLogger::PINFO );
+						}
+						else
+						{
+							SMTLogger::getInstance()->trace("changePassword >> Failed to change password for User $login", SMTLogger::ERROR );
+							throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_FAILED_TO_UPDATE_USER_PASSWORD_FILE );
+						}
+    				}
+    				else if ( self::checkSmartOtuGuestUnixLogin($login) )
+    				{
+    					//update linux password for guest user
+    					if ( self::changeSmartOtuGuestUnixLogin($newLogin) === TRUE )
+    					{
+    						SMTLogger::getInstance()->trace("changePassword >> Successfully changed guest User $login login to $newLogin", SMTLogger::PINFO );
+    					}
+    					else
+    					{
+    						SMTLogger::getInstance()->trace("Failed to update aliases file. Failed to change guest User $login to $newLogin", SMTLogger::ERROR );
+    						throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_FAILED_TO_UPDATE_USER_PASSWORD_FILE );
+    					}
+    					sleep(1); //#EPT9328
+    					if ( self::changeSmartOtuGuestUnixPassword($newPassword) === TRUE )
+    					{
+    						SMTLogger::getInstance()->trace("changePassword >> Successfully changed User $login password", SMTLogger::PINFO );
+    					}
+    					else
+    					{
+    						SMTLogger::getInstance()->trace("changePassword >> Failed to change password for guest User $login", SMTLogger::ERROR );
+    						throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_FAILED_TO_UPDATE_USER_PASSWORD_FILE );
+    					}
+    				}
 
 					// Si la migration n'a pas deja ete effectuee et si l'on est loggue en super user, on a change le login/password. Il faut effacer l'ancien fichier
 					if ( self::isOldPasswordFile() )
 					{
 					    //truncate and delete file to avoid a new migration
-					    $fp = fopen(self::PASSWD, "w");
+					    $fp = fopen(self::OLD_PASSWD_FILE, "w");
 					    fclose($fp);
 					    
-					    unlink(self::PASSWD);
+					    unlink(self::OLD_PASSWD_FILE);
 					}
     			}
     			else
@@ -391,9 +450,8 @@ class SMTUserUtil
         //migration du group install uniquement
     	if ( $fileRole === SMTRoleDto::INSTALL )
     	{
-    	    // password is in old file: migrate password, except if it is the default password. 
-    	    // If the old file contains the default password, we must check in Unix password file.
-    	    if ( $oldFilePassword != self::DEFAULT_INSTALL_PASSWORD_SHA_256 )
+    	    // password is in old file: migrate password, except if it is already in the unix file. 
+    		if ( !self::checkSmartOtuUnixPassword($password) )
     	    {
     	        //check password from old file
     	        if ( $password_sha_256 === $oldFilePassword)
@@ -431,7 +489,7 @@ class SMTUserUtil
     	        
     	        SMTLogger::getInstance()->trace("oldPasswordMigration >> Default password found, don't change User $login password", SMTLogger::PINFO );
     	    }
-    	    
+    	    sleep(1); //#EPT9328
     	    //migrate login if password change is successfull OR if no password migration was required and password check is successful
     	    if ( self::changeSmartOtuUnixLogin($login) === TRUE )
     	    {
@@ -485,7 +543,7 @@ class SMTUserUtil
     private static function isEnhancedSecurityOption( SMTContext $context )
     {
         // #trac 2922
-    	$isEnhancedSecurityMode = FALSE;
+    	$isEnhancedSecurityMode = TRUE;
     	try
     	{
     		$isEnhancedSecurityMode = SMTLicence::isHighSecurityMode($context);
@@ -497,6 +555,28 @@ class SMTUserUtil
     	return $isEnhancedSecurityMode;
     }
     
+    /**
+     * Test whether OTU has root access option.
+     *
+     * @param SMTContext $context
+     *
+     * @return whether the OTU is in high security mode.
+     */
+    private static function isRootAccessSecurityOption( SMTContext $context )
+    {
+    	// #trac 2922
+    	$isRootAccess = FALSE;
+    	try
+    	{
+    		$isRootAccess= SMTLicence::isHighSecurityMode($context) && SMTLicence::isSshKeyRootAccessOption($context);
+    	}
+    	catch( \Exception $e )
+    	{
+    		$context->getLogger()->traceException($e);
+    	}
+    	return $isRootAccess;
+    }
+    
     /**
      * Check SmartOtu unique password from /etc/shadow file
      *
@@ -535,6 +615,25 @@ class SMTUserUtil
     	return ($success == 0)? true : false;
     }
     
+    /**
+     * Check user password
+     *
+     * @return whether the password is valid
+     */
+    private static function checkUserPassword($login, $password)
+    {
+    	$success = -1;
+    	$command = sprintf( "sudo /usr/lib/jdsu/scripts/check_user_password.sh %s %s", SMTUtil::escapeShellArgUtf8($login), SMTUtil::escapeShellArgUtf8($password) );
+    	
+    	// check if user password is valid from /etc/shadow file
+    	$value = exec ($command, $output, $success);
+    	// SMTLogger::getInstance()->trace(sprintf("check password input: $password, output: %s", print_r($output,true)) );
+    	SMTLogger::getInstance()->trace(sprintf("checkUserPassword >> check password output: %s success %s", $value, $success) );
+    	
+    	// 0 -> password OK, otherwise KO
+    	return ($success == 0)? true : false;
+    }
+    
     /**
      * Change SmartOtu unique password
      *
@@ -542,13 +641,32 @@ class SMTUserUtil
      */
     private static function changeSmartOtuUnixPassword($newPassword)
     {
-        $success = -1;
+    	$success = -1;
     	$command = sprintf( "sudo /usr/lib/jdsu/scripts/change_smartotu_password.sh %s", SMTUtil::escapeShellArgUtf8($newPassword) );
+    	
+    	// change smartotu user password in /etc/shadow file
+    	$value = exec ($command, $output, $success);
+    	
+    	SMTLogger::getInstance()->trace(sprintf("changeSmartOtuUnixPassword >> change password output: %s success %s", $value, $success) );
+    	
+    	// 0 -> password change OK, otherwise KO
+    	return ($success == 0)? true : false;
+    }
+    
+    /**
+     * Change SmartOtu guest password
+     *
+     * @return whether the password was successfully changed
+     */
+    private static function changeSmartOtuGuestUnixPassword($newPassword)
+    {
+        $success = -1;
+    	$command = sprintf( "sudo /usr/lib/jdsu/scripts/change_smartotuguest_password.sh %s", SMTUtil::escapeShellArgUtf8($newPassword) );
     
     	// change smartotu user password in /etc/shadow file
     	$value = exec ($command, $output, $success);
 
-    	SMTLogger::getInstance()->trace(sprintf("changeSmartOtuUnixPassword >> change password output: %s success %s", $value, $success) );
+    	SMTLogger::getInstance()->trace(sprintf("changeSmartOtuGuestUnixPassword >> change password output: %s success %s", $value, $success) );
     
     	// 0 -> password change OK, otherwise KO
     	return ($success == 0)? true : false;
@@ -573,6 +691,25 @@ class SMTUserUtil
     	return ($success == 0)? true : false;
     }
     
+    /**
+     * Change SmartOtu guest login
+     *
+     * @return whether the login was successfully changed
+     */
+    private static function changeSmartOtuGuestUnixLogin($newLogin)
+    {
+    	$success = -1;
+    	$command = sprintf( "sudo /usr/lib/jdsu/scripts/change_user_login.sh %s %s", self::SMARTOTU_GUEST_USER, SMTUtil::escapeShellArgUtf8($newLogin) );
+    	
+    	// change smartotu user login (alias)
+    	$value = exec ($command, $output, $success);
+    	
+    	SMTLogger::getInstance()->trace(sprintf("changeSmartOtuGuestUnixLogin >> change login output: %s success %s", $value, $success) );
+    	
+    	// 0 -> login change OK, otherwise KO
+    	return ($success == 0)? true : false;
+    }
+    
     /**
      * Check SmartOtu login from aliases
      *
@@ -604,6 +741,68 @@ class SMTUserUtil
     	return $success;
     }
     
+    /**
+     * Check Guest login from aliases
+     *
+     * @return whether the login is valid
+     */
+    private static function checkSmartOtuGuestUnixLogin($login)
+    {
+    	$success = FALSE;
+    	
+    	if ( is_file(self::USER_ALIASES_FILE) )
+    	{
+    		$info = file(self::USER_ALIASES_FILE);
+    		foreach ($info as $line)
+    		{
+    			if ( ($line != "") && (strpos( $line, ':' ) !== FALSE) )
+    			{
+    				list($file_login, $user_name) = explode(":",$line);
+    				$user_name = trim($user_name);
+    				$file_login = trim($file_login);
+    				if ( (strcmp($user_name, self::SMARTOTU_GUEST_USER) == 0) && ($login === $file_login) )
+    				{
+    					$success = TRUE;
+    					SMTLogger::getInstance()->trace("checkSmartOtuGuestUnixLogin >> check login successful for user: $login" );
+    					break;
+    				}
+    			}
+    		}
+    	}
+    	return $success;
+    }
+    
+    /**
+     * login of smartotuguest user retrieved from /etc/aliases file 
+     * 
+     * @return string
+     */
+    public static function getSmartOTUGuestLogin()
+    {
+    	$login = "";
+    	
+    	if ( is_file(self::USER_ALIASES_FILE) )
+    	{
+    		$info = file(self::USER_ALIASES_FILE);
+    		foreach ($info as $line)
+    		{
+    			if ( ($line != "") && (strpos( $line, ':' ) !== FALSE) )
+    			{
+    				list($file_login, $user_name) = explode(":",$line);
+    				$user_name = trim($user_name);
+    				$file_login = trim($file_login);
+    				if ( strcmp($user_name, self::SMARTOTU_GUEST_USER) == 0 )
+    				{
+    					$login= $file_login;
+    					SMTLogger::getInstance()->trace("getSmartOTUGuestLogin >> get login successful for user: $login" );
+    					break;
+    				}
+    			}
+    		}
+    	}
+    	return $login;
+    }
+    
     /**
      * * Check SmartOtu login from /etc/aliases file, and create the smartotu user if it doesn't exist (first install)
      *
@@ -726,7 +925,7 @@ class SMTUserUtil
      */
     private static function isOldPasswordFile()
     {
-    	return ( is_file(self::PASSWD) && (filesize(self::PASSWD) > 0) );
+    	return ( is_file(self::OLD_PASSWD_FILE) && (filesize(self::OLD_PASSWD_FILE) > 0) );
     }
 
     /**
@@ -764,7 +963,7 @@ class SMTUserUtil
 	    	$userRole = $context->getUser()->getRole();
 	    	if ( ($userRole != NULL) && (SMTOtuMode::isONMSi() || SMTOtuMode::isSmartOem() || SMTOtuMode::isROTAU()|| self::isLocalModeForCurrentSession( $context ) ) )
 	    	{
-	    		if ( !$userRole->isEqual( SMTRoleDto::SUPER_USER) && !$userRole->isEqual(SMTRoleDto::DEBUG) )
+	    		if ( !$userRole->isEqual( SMTRoleDto::SUPER_USER) && !$userRole->isEqual(SMTRoleDto::DEBUG) && (!$userRole->isEqual(SMTRoleDto::USER) ) )
 	    		{
 	    			$userRoleName = SMTRoleDto::INSTALL_IP;
 	    			$context->getUser()->setRole($userRoleName);
