@@ -18,7 +18,6 @@ use Luracast\Restler\Defaults;
 
 use app\view\SMTIPage;
 use app\error\SMTRestExceptionFactory;
-use app\util\SMTDto;
 
 /**
  * Http response
@@ -41,6 +40,7 @@ class SMTHttpResponse
 	
 	public function redirect($location)
 	{
+	    //header('Refresh: 1; url='.$location);
 		header('Location: '.$location);
 		exit;
 	}
@@ -142,7 +142,7 @@ class SMTHttpResponse
      */
     public static function handleApiError( SMTContext $context, $httpErrorCode, $status, $message)
     {
-    	$context->closeSession();
+    	$context->closeSession('api error');
     	
     	$responseFormat = new JsonFormat();
     	$responseFormat->setCharset(Defaults::$charset);
