@@ -153,6 +153,8 @@ class SMTOtuApi
     const RES_ENABLE = 'ENABLE';
     const RES_DISABLE = 'DISABLE';
     
+    const SEQUENTIAL = "SEQU";
+    
     const OTU_MAX_ADDITIONAL_INFO_LENGTH = 30;
     
     /**
@@ -404,6 +406,20 @@ class SMTOtuApi
     const CMD_get_DWDM_MOD = 'OTU:WDM:MOD?';
     
     const CMD_check_module_compatibility_with_switch = 'OTU:MODU:SWITCH:COMP?';
+    
+    
+    const CMD_Select_Module = 'OTU:MODULE:SELECT %s,"%s"';
+    /**
+     * Select given module, function in Isu and FO
+     * @param string $module
+     * @param string $function
+     * @return string
+     */
+    static function getModuleSelectFunctionCommand($module, $function)
+    {
+        return sprintf( self::CMD_Select_Module, $module, $function );
+    }
+    
     //modems configuration:
 //     const CMD_modem_media_config = 'OTU:MED:GET? BACK';
 //     const CMD_modem_speed = 'otu:modem:conf:spee? %s'; //INT1 ...
@@ -1281,6 +1297,17 @@ class SMTOtuApi
     	return self::CMD_meas_status;
     }
     
+    const CMD_fo_meas_status = 'STATUS:ACQ?';
+    /**
+     * Get the status of the running measure launched with CMD_acquisition_on_link_SI command
+     *
+     * @return string
+     */
+    static function getFoMeasurementStatus( )
+    {
+        return self::CMD_fo_meas_status;
+    }
+    
     const CMD_stop_measure = 'OTU:MEAS:STOP';
     /**
      * Stop the current running measure command
@@ -1377,6 +1404,18 @@ class SMTOtuApi
      return self::CMD_Virtual_Switch_Port_Count;   
     }
     
+    const CMD_interrupt_otu_sequencer ='OTU:ABORT:SUSPEND';
+    /**
+     * interrupt OTU sequencer
+     *
+     *
+     * @return string
+     */
+    static function getInterruptOtuSequencerCommand()
+    {
+        return self::CMD_interrupt_otu_sequencer;
+    }
+    
     const CMD_link_change_gps_file = 'OTU:LINK:GPS:FILE %d,"%s"';
     /**
      * Update link GPS file name
@@ -1619,6 +1658,59 @@ class SMTOtuApi
     	return sprintf( self::CMD_set_test_mon_available, $testId, $available);
     }
     
+    const CMD_Fo_Setup_Measurement = 'FSETUP:LOAD? "%s","%s",expert';
+    /**
+     * Get the command to set the measurement
+     *
+     * @param string $dir
+     * @param string $fileName
+     *
+     * @return string
+     */
+    static function getLoadMeasurementCommand( $dir, $fileName )
+    {
+        return sprintf( self::CMD_Fo_Setup_Measurement, $dir, $fileName );
+    }    
+    
+    const CMD_Fo_Reset_Ref = 'PARam:LOCKreference FALSE';
+    const CMD_Fo_Unlock_Marker = 'OTDS:LMARKER NO';
+    const CMD_Fo_Result = 'KEY RESULT';
+    const CMD_Fo_Start_Measurement = 'ACQ:START';
+    /**
+     * Get the command to start the measurement
+     *
+     *
+     * @return string
+     */
+    static function getStartMeasurementCommand()
+    {
+        return self::CMD_Fo_Start_Measurement;
+    }  
+    
+    const CMD_MEASUREMENT_FILE_NAME = 'FSETUP:ASTORE YES;FSETUP:DIRN "%s";FSETUP:FNAMING "%s";FSETUP:FCMultitrace YES;FSETUP:RESults ONEF;FSETUP:FSMODE FPDF;FSET:RJSON YES';
+    /**
+     * Get the command to start the measurement
+     *
+     *
+     * @return string
+     */
+    static function getMeasurementFileNamingCommand($dir, $name)
+    {
+        return sprintf(self::CMD_MEASUREMENT_FILE_NAME, $dir, $name);
+    }  
+    
+    const CDM_FORCE_RESET_ACQ_PARAM_AFTER_MEASUREMENT = 'OTU:FOSetup:RESET';
+    /**
+     * Get the command to force the reset of acquisition parameters after the current measurement 
+     *
+     *
+     * @return string
+     */
+    static function getForceResetFoSetupCommand()
+    {
+        return self::CDM_FORCE_RESET_ACQ_PARAM_AFTER_MEASUREMENT;
+    }  
+
     /**
      * testId
      */
@@ -1666,7 +1758,23 @@ class SMTOtuApi
     	return sprintf(self::CMD_set_mon_seq_status, $status );
     }
     
+    const CMD_FO_acq_stop = 'ACQ:STOP';
     
+    /**
+     *  
+     */
+    const CMD_switch_commut = 'OTU:SWITCH:COMMUT %d,%d,%d';
+    /**
+     * Set switch port command
+     *
+     * @param int $macroSwitch
+     * @param int $in
+     * @param int $out
+     */
+    static function setSwitchCommuteCommand( $macroSwitch, $in, $out)
+    {
+        return sprintf(self::CMD_switch_commut, $macroSwitch, $in, $out );
+    }
     
     /**
      *  [WAIT, ENABLE, DISABLE]
