@@ -1,10 +1,11 @@
 <?php
 define("MSG_BAD_CREDENTIALS","Les identifiants fournis (nom d’utilisateur ou mot de passe) sont invalides.");
+define("MSG_BAD_DMUX","Impossible d'ajouter le Dmux %s, avec la grille %s et les ports %d");
 define("MSG_BAD_THRESHOLD_VALUE","La valeur de seuil %s est incorrecte pour le champs: %s");
 define("MSG_BAD_ROTAU_IP","Impossible de se connecter au ROTAU d'adresse %s");
 define("MSG_CHINESE","中文");
 define("MSG_CONNECTION","Connexion");
-define("MSG_COPYRIGHT_SHORT","Copyright © 2022 VIAVI. Tous droits réservés.");
+define("MSG_COPYRIGHT_SHORT","Copyright © 2025 VIAVI. Tous droits réservés.");
 define("MSG_ENGLISH","English");
 define("MSG_ERROR_ADD_LOCALISATION_ERROR","Erreur d ajout de localisation!"); 
 define("MSG_ERROR_ALARM_UNDEFINED","Alarme inconnue");
@@ -255,6 +256,7 @@ define("FIBER_BREAK","Coupure Fibre");
 define("SPLICE_ATTENUATION","Courbure fibre au niveau d'une épissure ou d'un patchcord APC");
 define("CONNECTOR_ATTENUATION","Courbure au niveau d'un connecteur, connecteur sale ou mal connecté");
 define("FIBER_ATTENUATION","Courbure fibre");
+define("NEW_REFERENCE_REQUIRED","Fibre modifiée: Requiert une nouvelle référence");
 define("UNKNOW_ALARM","Alarme inconnue");
 define("UNKNOWN_CAUSE","Cause inconnue");
 ?>
