@@ -22,10 +22,15 @@ use app\error\SMTRestException;
 use app\events\operations\SMTOperationEventDto;
 use app\http\SMTHttpResponse;
 use app\serviceshelper\monitoring\SMTLinkTest;
+use app\serviceshelper\monitoring\SMTMeasureOnDemandException;
 use app\serviceshelper\monitoring\SMTTestOnDemand;
 use app\serviceshelper\monitoring\SMTTestOnDemandException;
 use app\util\SMTInvalidValueException;
 use app\util\SMTUtil;
+use app\serviceshelper\otdr\SMTMeasurementInstrument;
+use app\serviceshelper\otdr\SMTOtdrTraceType;
+use app\util\SMTLogger;
+use app\view\SMTMeasureResultFileDownloadPage;
 
 
 /**
@@ -549,5 +554,174 @@ class SMTApiPortService extends SMTService implements SMTIService
 		return $statusDto->getJsonData();
 	}
 	
+	
+	/**
+	 *
+	 * @url POST /{portNumber}/measureOnDemand/status
+	 *
+	 * @access protected
+	 * @class SMTAccessControl {@requires install}
+	 */
+	function getMeasureOnDemandOnPortStatus( $portNumber )
+	{
+	    $measureStatusDto = new SMTApiMeasureInstrumentStatusDto();
+	    $measureOnDemandHelper = new SMTMeasurementInstrument(  );
+	    $measureOnDemandHelper->setContext( $this->getContext() );
+	    try 
+	    {
+	        $measureStatusDto = $measureOnDemandHelper->getMeasurementStatusFromPort( $portNumber );
+    	}
+    	catch ( \Exception $e )
+    	{
+    	    $this->getContext()->getLogger()->traceException($e);
+    	    $measureStatusDto->setStatus(SMTApiMeasureInstrumentStatusDto::FAILURE);
+    	    $message = 'Failed to start measure on demand on port '.$portNumber;
+    	    SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, $measureStatusDto->getStatus(), $message);
+    	}
+	    
+	    $this->getContext()->closeSession('api');
+	    
+	    return $measureStatusDto->getJsonData();
+	}
+	
+	/**
+	 *
+	 * @url POST /{portNumber}/measureOnDemand
+	 *
+	 * @access protected
+	 * @class SMTAccessControl {@requires install}
+	 */
+	function startMeasureOnDemandOnPort( $portNumber, $request_data )
+	{
+	    $this->checkApi();
+	    $port = intval($portNumber);
+	    $measureStatusDto = new SMTApiMeasureInstrumentStatusDto();
+	    $measurementDto = SMTApiMeasurementDto::getInstance( $request_data );
+	    
+	    $linkHelper = new SMTLinkTest();
+	    $linkHelper->setContext( $this->getContext() );
+	    $portCount = $linkHelper->getPortsCount();
+	    
+	    if ( ($port > $portCount) || ($port < 1) )
+	    {
+	        SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::BAD_REQUEST, SMTApiDto::FAILURE, "Invalid port number ".$port);	        
+	    }
+
+        try
+        {            
+            $measureOnDemandHelper = new SMTMeasurementInstrument(  );
+            $measureOnDemandHelper->setContext( $this->getContext() );
+            $status = $measureOnDemandHelper->startMeasure( $measurementDto, $port );
+        }
+        catch( SMTMeasureOnDemandException $ex )
+        {
+            $this->getContext()->getLogger()->traceException($ex);
+            if ( strcasecmp($ex->getErrorCode(), SMTOperationEventDto::ERROR_ONE_MEASURE_ON_DEMAND) == 0 )
+            {
+                $measureStatusDto->setStatus(SMTApiMeasureInstrumentStatusDto::MEASURE_ALREADY_RUNNING);
+                $message = 'One measure already runnning';
+            }
+            else
+            {
+                $measureStatusDto->setStatus(SMTApiMeasureInstrumentStatusDto::FAILURE);
+                $message = 'Failed to start measure on demand on port '.$portNumber;
+            }
+            SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, $measureStatusDto->getStatus(), $message);
+        }
+        catch ( \Exception $e )
+        {
+            $this->getContext()->getLogger()->traceException($e);
+            $measureStatusDto->setStatus(SMTApiMeasureInstrumentStatusDto::FAILURE);
+            $message = 'Failed to start measure on demand on port '.$portNumber;
+            SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, $measureStatusDto->getStatus(), $message);
+        }
+        
+        if ( $status != NULL && !$status->isOperationRunning() )
+        {
+            $measureStatusDto->setStatus(SMTApiMeasureInstrumentStatusDto::FAILURE);
+            $message = 'Failed to start measure on demand on port '.$portNumber;
+            SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, $measureStatusDto->getStatus(), $message);
+        }
+	    $this->getContext()->closeSession('api');
+	    
+	    return $measureStatusDto->getJsonData();
+	}
+	
+	
+	
+	/**
+	 * Retrieve OTDR acquisition, CDM & json file
+	 * 
+	 * @url POST /{portNumber}/measureOnDemand/result
+	 *
+	 * @access protected
+	 * @class SMTAccessControl {@requires install}
+	 */
+	function downloadResultFile($portNumber, $request_data)
+	{
+	    SMTLogger::getInstance()->trace( sprintf("Retrieve measurement file for type %s", json_encode($request_data)), SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);
+
+	    $port = intval($portNumber);
+	    $resultType = trim($request_data['resultType'],"\"");
+	    
+	    $linkHelper = new SMTLinkTest();
+	    $linkHelper->setContext( $this->getContext() );
+	    $portCount = $linkHelper->getPortsCount();
+	    
+	    if ( ($port > $portCount) || ($port < 1) )
+	    {
+	        SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::BAD_REQUEST, SMTApiDto::FAILURE, "Invalid port number ".$port);
+	    }
+	    
+	    try
+	    {
+	        if ( SMTOtdrTraceType::isMeasurementResultFileType( $resultType) )
+	            {
+	                switch ($resultType)
+	                {
+	                    case SMTOtdrTraceType::ACQUISITION_FILE:
+	                        $traceFilePath = SMTMeasurementInstrument::getTraceFileName($port);
+	                        break;
+	                    case SMTOtdrTraceType::CDM_FILE:
+	                        $traceFilePath = SMTMeasurementInstrument::getCDMFileName($port);
+	                        break;
+	                    case SMTOtdrTraceType::PDF_FILE:
+	                        $traceFilePath = SMTMeasurementInstrument::getPdfFileName($port);
+	                        break;
+	                    default:
+	                        $measureStatusDto = new SMTApiMeasureInstrumentStatusDto( SMTApiMeasureInstrumentStatusDto::FAILURE, "invalid result type ".$resultType );
+	                        SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, $measureStatusDto->getStatus(), "invalid result type ".$resultType);
+	                        break;
+	                }
+	                
+	                SMTLogger::getInstance()->trace( sprintf("Retrieve measurement file %s, for type %s ",  $traceFilePath, $resultType), SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);
+	                $page = new SMTMeasureResultFileDownloadPage( $traceFilePath );
+	                $this->getContext()->getHttpResponse()->send( $page, FALSE );
+
+	                //delete file downloaded before exit
+	                SMTMeasurementInstrument::deleteFile($traceFilePath);
+	                
+	                $this->getContext()->closeSession('api');
+
+	                exit(0);
+	            }
+	            else
+	            {
+	                $measureStatusDto = new SMTApiMeasureInstrumentStatusDto( SMTApiMeasureInstrumentStatusDto::FAILURE, "invalid result type ".$resultType );
+	                SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, $measureStatusDto->getStatus(), "invalid result type ".$resultType);
+	            }
+	    }
+	    catch ( SMTException $e )
+	    {
+	        $ex = new SMTRestException( SMTRestException::SERVICE_NOT_FOUND , $e->getMessage()." ".$e->getDetailedMessage(), $e->getCode(), $e->getTrace() );
+	        $this->handleException($ex);
+	    }
+	    catch ( SMTException $catchAll )
+	    {
+	        $ex = new SMTRestException( SMTRestException::SERVICE_NOT_FOUND , $catchAll->getMessage(), $catchAll->getCode(), $catchAll->getTrace() );
+	        $this->handleException($ex);
+	    }
+	}
+	
 }
 
