@@ -59,7 +59,7 @@ class SMTApiUrlService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve monitoring summary url');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $url;
 	}
@@ -87,7 +87,7 @@ class SMTApiUrlService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve otu setup url');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $url;
 	}
@@ -128,7 +128,7 @@ class SMTApiUrlService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve last acquisition url');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $url;
 	}
@@ -169,7 +169,7 @@ class SMTApiUrlService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve monitoring test url');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $url;
 	}
@@ -210,7 +210,7 @@ class SMTApiUrlService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve alarm url');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $url;
 	}
