@@ -557,19 +557,22 @@ class SMTLinkTestService extends SMTService implements SMTIService
     		}
     		
     		//retrieve links ids
-    		$linksId = explode(",", $this->sendReceive( SMTOtuApi::getLinkListPerPortCommand($paginationDto->getFirstElementId(), min($paginationDto->getLastElementId(), $portCount) ) ) );
-    		$linkTestDto = NULL;
-    		foreach ( $linksId as $linkId)
+    		if ($portCount > 0)
     		{
-    		    if ( SMTLinkTest::checkLinkTestId( $linkId, FALSE) )
-    		    {
-        		    $linkTestDto = $linkHelper->retrieveLinkTest( $linkId, $sequensorOn, $portCount );
-        		    if ( $linkTestDto != NULL )
+        		$linksId = explode(",", $this->sendReceive( SMTOtuApi::getLinkListPerPortCommand($paginationDto->getFirstElementId(), min($paginationDto->getLastElementId(), $portCount) ) ) );
+        		$linkTestDto = NULL;
+        		foreach ( $linksId as $linkId)
+        		{
+        		    if ( SMTLinkTest::checkLinkTestId( $linkId, FALSE) )
         		    {
-        		        $linkTestListDto->addLinkTest( $linkTestDto );
-        		    }
-    		    }    		    
-    		}		
+            		    $linkTestDto = $linkHelper->retrieveLinkTest( $linkId, $sequensorOn, $portCount );
+            		    if ( $linkTestDto != NULL )
+            		    {
+            		        $linkTestListDto->addLinkTest( $linkTestDto );
+            		    }
+        		    }    		    
+        		}
+    		}
     	}
     	catch ( \Exception $e )
     	{
