@@ -71,6 +71,12 @@ class SMTConfDetSwitchDto extends SMTRwDto
 	 */
 	protected $otamSwitch = FALSE;
 	
+	/**
+	 * Whether the OTU uses HDOS
+	 * @var boolean
+	 */
+	protected $hdosSwitch = FALSE;
+	
 	/**
 	 * Whether the OTU supports OTAM
 	 * @var boolean
@@ -153,6 +159,15 @@ class SMTConfDetSwitchDto extends SMTRwDto
 		}
 	}
 	
+	/**
+	 *
+	 * @param boolean $hasHDOSSwitch
+	 */
+	function setHDOSSwitch( $hasHDOSSwitch)
+	{
+	    $this->hdosSwitch = $hasHDOSSwitch;
+	}
+	
 	/**
 	 *
 	 * @param boolean $otamPossible
