@@ -17,6 +17,8 @@ use app\util\SMTRwDto;
 
 class SMTIpv4Dto extends SMTRwDto
 {
+    const DEFAULT_ADDRESS = '0.0.0.0';
+    
     /**
      * @var boolean
      */
@@ -49,17 +51,38 @@ class SMTIpv4Dto extends SMTRwDto
         
     public function setIp( $ip )
     {
-    	$this->ip = $ip;
+        if ( empty($ip) )
+        {
+            $this->ip=self::DEFAULT_ADDRESS;
+        }
+        else
+        {
+    	   $this->ip = $ip;
+        }
     }
         
     public function setSubnet( $subnet )
     {
-    	$this->subnet = $subnet;
+        if ( empty($subnet) )
+        {
+            $this->subnet=self::DEFAULT_ADDRESS;
+        }
+        else
+        {
+    	   $this->subnet = $subnet;
+        }
     }    
     
     public function setGateway( $gateway )
     {
-    	$this->gateway = $gateway;
+        if ( empty($gateway) )
+        {
+            $this->gateway=self::DEFAULT_ADDRESS;
+        }
+        else
+        {
+    	   $this->gateway = $gateway;
+        }
     }
 
     public function setDomain( $domain )
@@ -69,7 +92,14 @@ class SMTIpv4Dto extends SMTRwDto
 
     public function setDns( $dns )
     {
-    	$this->dns = $dns;
+        if ( empty($dns) )
+        {
+            $this->dns=self::DEFAULT_ADDRESS;
+        }
+        else
+        {
+    	   $this->dns = $dns;
+        }
     }    
     
     public function isDHCP()
@@ -105,7 +135,16 @@ class SMTIpv4Dto extends SMTRwDto
     public function getDns()
     {
     	return $this->dns;
-    }    
+    }
+    
+    public function initDefault()
+    {
+        $this->ip=self::DEFAULT_ADDRESS;
+        $this->subnet=self::DEFAULT_ADDRESS;
+        $this->gateway=self::DEFAULT_ADDRESS;
+        $this->dns=self::DEFAULT_ADDRESS;
+        $this->domain='';
+    }
     
     public function stripHtmlTags()
     {
