@@ -53,8 +53,8 @@ class SMTModuleService extends SMTService implements SMTIService
             }
             else
             {
-        	    $this->send( SMTOtuApi::CMD_config );
-            }        	
+            	$this->getContext()->getOtuSocket()->send( SMTOtuApi::CMD_config, 0, 90 );//1mn30 of timeout for apply module config : can be long if check hardware with invalid switches
+            }
         	
         	
         	SMTMemoryManager::deleteAll( SMTModuleDto::getClass() );
