@@ -113,6 +113,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     	    $configDetectSwitchDto->setIsOsxPowerOn($this->getSwitchManager(TRUE)->getOsxPowerOn());
     	    $configDetectSwitchDto->setOTAMPossible($this->getSwitchManager(TRUE)->isMolexSwitchPossible());
     	    $configDetectSwitchDto->setOTAMSwitch($this->getSwitchManager(TRUE)->hasMolexOSUDetected());
+    	    $configDetectSwitchDto->setHDOSSwitch($this->switchManager->hasUOSDetected());
     	    $configDetectSwitchDto->setModuleCompatibleWithSwitch($this->getSwitchManager(TRUE)->isModuleCompatibleWithSwitch());
     	    $configDetectSwitchDto->setModuleCompatibleWithDmuxSwitch(SMTDmuxManager::isDmuxSwitchSupported($this->getContext()) );
     	    $configDetectSwitchDto->setPortDistributorNumber($this->switchManager->getPortsDistributorNumber());
@@ -147,7 +148,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     		$this->switchManager->disableSequencer(FALSE);
     		
     		// si l'on n'est pas en mode SmartOTU, on force la detection si elle n'a jamais ete faite
-    		if ( !SMTOtuMode::isSmartOtuFamily() && !SMTOtuStatusCacheDto::getSwitchDetectedOnce() )
+    		if ( /*!SMTOtuMode::isSmartOtuFamily() &&*/ !SMTOtuStatusCacheDto::getSwitchDetectedOnce() )
     		{
     			$detectOsx = TRUE;
     		}
@@ -163,6 +164,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     		$configDetectSwitchDto->setIsOsxPowerOn($this->switchManager->getOsxPowerOn());
     		$configDetectSwitchDto->setOTAMPossible($this->switchManager->isMolexSwitchPossible());
     		$configDetectSwitchDto->setOTAMSwitch($this->switchManager->hasMolexOSUDetected());
+    		$configDetectSwitchDto->setHDOSSwitch($this->switchManager->hasUOSDetected());
     		$configDetectSwitchDto->setModuleCompatibleWithSwitch($this->switchManager->isModuleCompatibleWithSwitch());
     		$configDetectSwitchDto->setModuleCompatibleWithDmuxSwitch(SMTDmuxManager::isDmuxSwitchSupported($this->getContext()) );
     		$configDetectSwitchDto->setPortDistributorNumber($this->switchManager->getPortsDistributorNumber());
@@ -516,7 +518,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     	$configDetectRotauDto= new SMTConfDetRotauDto();
     	try
     	{
-    	    if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2()|| SMTOtuType::isCOtu() ) )
+    	    if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isFTH7K() || SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2()|| SMTOtuType::isCOtu() ) )
 	    	{
 	    		if ( $this->rotauManager== NULL )
 	    		{
@@ -549,7 +551,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     {
     	try
     	{
-    	    if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
+    	    if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isFTH7K() || SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
     		{
 	    		if ( $this->rotauManager== NULL )
 	    		{
@@ -582,7 +584,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     {
     	try
     	{
-    	    if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
+    	    if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOTH() || SMTOtuType::isFTH7K() || SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
     		{
 	    		if ( $this->rotauManager== NULL )
 	    		{
@@ -614,7 +616,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     {
     	try
     	{
-    	    if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
+    	    if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOTH() || SMTOtuType::isFTH7K() || SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
     		{
     			$configDetectRotauDto = SMTConfDetRotauDto::getInstance( $request_data );
     			if ( $configDetectRotauDto!= null)
@@ -685,36 +687,6 @@ class SMTSwitchService extends SMTService implements SMTIService
         return $dmuxConf->getJsonData();
     }
     
-    /**
-     *
-     * @url POST /dmux
-     *
-     * @access protected
-     * @class SMTAccessControl {@requires install}
-     */
-    function addDmux($request_data)
-    {
-        try
-        {
-            if ( SMTOtuMode::isONMSi() )
-            {
-                $dmuxManager= new SMTDmuxManager();
-                $dmuxManager->setContext( $this->getContext() );
-                $dmuxDto = SMTDmuxDto::getInstance( $request_data );
-                $dmuxManager->add($dmuxDto);
-            }
-            else
-            {
-                new SMTInvalidValueException(SMTInvalidValueException::INVALID_VALUE, NULL, "DMUX", "not supported");
-            }
-        }
-        catch ( \Exception $e )
-        {
-            $this->handleException($e);
-        }
-        return $this->fetchDmuxConfig();
-    }
-    
     /**
      *
      * @url DELETE /dmux/{$dmuxId}
