@@ -35,6 +35,7 @@ use app\services\alarm\SMTSystemAlarmDto;
 use app\services\alarm\otu\SMTOtuOpticalAlarmPeakDto;
 use app\services\alarm\SMTPeakOpticalAlarmDto;
 use app\services\alarm\SMTPeakOpticalAlarmEventDto;
+use app\http\SMTContext;
 
 
 define( "ATTENUATION_ALARM_DISCRIMINATOR_FORMAT", "test=%d".SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR.SMTAlarmSpecificProblemDiscriminatorCode::ATTENUATION_ALARM );
@@ -105,7 +106,7 @@ class SMTAlarmFactory
      * 
      * @return SMTAttenuationOpticalAlarmEventDto the alarm event created
      */
-    public static function updateAttenuationOpticalAlarmDto( SMTSmartOtuDB $dbConnection, SMTOtuOpticalAlarmDto $otuAlarm, SMTAttenuationOpticalAlarmDto $alarm = NULL, $alarmDiscriminator, $newAlarm = TRUE ) 
+    public static function updateAttenuationOpticalAlarmDto( SMTContext $context, SMTSmartOtuDB $dbConnection, SMTOtuOpticalAlarmDto $otuAlarm, SMTAttenuationOpticalAlarmDto $alarm = NULL, $alarmDiscriminator, $newAlarm = TRUE ) 
     {
         SMTLogger::getInstance()->trace( sprintf("Optical alarm attenuation with transition: %b. Alarm specific problem: %s.", SMTOtuAlarmSeverity::hasSeverityTransition( $otuAlarm->getOtuSeverity() ), $otuAlarm->getAttenuation()->getSpecificProblemCode()), SMTLogger::INFO );      	   
 	    
@@ -118,7 +119,7 @@ class SMTAlarmFactory
 			$alarmEvent = new SMTAttenuationOpticalAlarmEventDto();
 			$alarmEvent->setAlarmId( $alarm->getId() );
 			$alarmEvent->setSeverity( $otuAlarm->getAttenuation()->getSeverityConvertedToSmartOtu() );
-			$alarmEvent->setTime( $otuAlarm->getGenerationDateUTC( $dbConnection ) );    				
+			$alarmEvent->setTime( $otuAlarm->getGenerationDateUTC( $context ) );    				
 			$alarmEvent->setProblemConfirmed( $otuAlarm->isConfirmed() );
 			
 			if ( $otuAlarm->getAttenuation()->isValidDistance() )
@@ -211,7 +212,7 @@ class SMTAlarmFactory
      *
      * @return SMTAttenuationOpticalAlarmDto the alarm created
      */
-    public static function createAttenuationOpticalAlarmDto( SMTSmartOtuDB $dbConnection, SMTOtuOpticalAlarmDto $otuAlarm, $alarmDiscriminator )
+    public static function createAttenuationOpticalAlarmDto( SMTContext $context, SMTSmartOtuDB $dbConnection, SMTOtuOpticalAlarmDto $otuAlarm, $alarmDiscriminator )
     {
     	SMTLogger::getInstance()->trace( sprintf("Create Optical alarm attenuation with transition: %b. Alarm specific problem: %s.", SMTOtuAlarmSeverity::hasSeverityTransition( $otuAlarm->getOtuSeverity() ), $otuAlarm->getAttenuation()->getSpecificProblemCode()), SMTLogger::INFO );
     
@@ -226,7 +227,7 @@ class SMTAlarmFactory
     		$alarm->setTestId( $otuAlarm->getTestId() );    		
     		$alarm->setDiscriminator( $alarmDiscriminator );
     		$alarm->setAlarmType( SMTAlarmEventTypeCode::OTU_ALARM_EVENT_TYPE_QUALITY_OF_SERVICE_ALARM );    		  	
-    		$alarm->setLastUpdate( $otuAlarm->getGenerationDateUTC( $dbConnection ) );    		
+    		$alarm->setLastUpdate( $otuAlarm->getGenerationDateUTC( $context ) );    		
     		
   		    $severity = $otuAlarm->getSeverityConvertedToSmartOtu();    		    
     				
@@ -266,7 +267,7 @@ class SMTAlarmFactory
      *
      * @return SMTPeakOpticalAlarmDto the alarm created
      */
-    public static function createPeakOpticalAlarmDto( SMTSmartOtuDB $dbConnection, SMTOtuOpticalAlarmDto $otuAlarm, SMTOtuOpticalAlarmPeakDto $peakAlarmDto, $alarmDiscriminator )
+    public static function createPeakOpticalAlarmDto( SMTContext $context, SMTSmartOtuDB $dbConnection, SMTOtuOpticalAlarmDto $otuAlarm, SMTOtuOpticalAlarmPeakDto $peakAlarmDto, $alarmDiscriminator )
     {
     	SMTLogger::getInstance()->trace( sprintf("Create peak optical alarm with transition: %b. Alarm specific problem: %s.", SMTOtuAlarmSeverity::hasSeverityTransition( $peakAlarmDto->getOtuSeverity() ), SMTAlarmSpecificProblemCode::OTU_OPT_ALARM_PEAK_CODE), SMTLogger::INFO );
     	
@@ -281,7 +282,7 @@ class SMTAlarmFactory
     		$alarm->setTestId( $otuAlarm->getTestId() );
     		$alarm->setDiscriminator( $alarmDiscriminator );
     		$alarm->setAlarmType( SMTAlarmEventTypeCode::OTU_ALARM_EVENT_TYPE_QUALITY_OF_SERVICE_ALARM );
-    		$alarm->setLastUpdate( $otuAlarm->getGenerationDateUTC( $dbConnection ) );
+    		$alarm->setLastUpdate( $otuAlarm->getGenerationDateUTC( $context ) );
     		$alarm->setSpecificProblemCode( SMTAlarmSpecificProblemCode::OTU_OPT_ALARM_PEAK_CODE);
     		
     		$severity = $peakAlarmDto->getSeverityConvertedToSmartOtu();
@@ -320,7 +321,7 @@ class SMTAlarmFactory
      *
      * @return SMTPeakOpticalAlarmEventDto the alarm event created
      */
-    public static function updatePeakOpticalAlarmDto( SMTSmartOtuDB $dbConnection, SMTOtuOpticalAlarmDto $otuAlarm, SMTOtuOpticalAlarmPeakDto $peakAlarmDto, SMTPeakOpticalAlarmDto $alarm = NULL, $alarmDiscriminator, $newAlarm = TRUE )
+    public static function updatePeakOpticalAlarmDto( SMTContext $context, SMTSmartOtuDB $dbConnection, SMTOtuOpticalAlarmDto $otuAlarm, SMTOtuOpticalAlarmPeakDto $peakAlarmDto, SMTPeakOpticalAlarmDto $alarm = NULL, $alarmDiscriminator, $newAlarm = TRUE )
     {
     	SMTLogger::getInstance()->trace( sprintf("Peak Optical alarm with transition: %b. Alarm specific problem: %s.", SMTOtuAlarmSeverity::hasSeverityTransition( $peakAlarmDto->getOtuSeverity() ), SMTAlarmSpecificProblemCode::OTU_OPT_ALARM_PEAK_CODE), SMTLogger::INFO );
     	
@@ -333,7 +334,7 @@ class SMTAlarmFactory
     		$alarmEvent = new SMTPeakOpticalAlarmEventDto();
     		$alarmEvent->setAlarmId( $alarm->getId() );
     		$alarmEvent->setSeverity( $peakAlarmDto->getSeverityConvertedToSmartOtu() );
-    		$alarmEvent->setTime( $otuAlarm->getGenerationDateUTC( $dbConnection ) );
+    		$alarmEvent->setTime( $otuAlarm->getGenerationDateUTC( $context ) );
     		$alarmEvent->setProblemConfirmed( $otuAlarm->isConfirmed() );
     		
     		$alarmEvent->setReferenceTopDistanceM( $peakAlarmDto->getReferenceTopDistance() );
@@ -407,7 +408,7 @@ class SMTAlarmFactory
      *
      * @return SMTSystemAlarmDto the alarm updated or created
      */
-    public static function createOrUpdateSystemAlarmDto( SMTSmartOtuDB $dbConnection, SMTOtuSystemAlarmDto $otuAlarm, SMTSystemAlarmDto $alarm = NULL, $alarmDiscriminator )
+    public static function createOrUpdateSystemAlarmDto( SMTContext $context, SMTSmartOtuDB $dbConnection, SMTOtuSystemAlarmDto $otuAlarm, SMTSystemAlarmDto $alarm = NULL, $alarmDiscriminator )
     {
     	SMTLogger::getInstance()->trace( sprintf("System alarm with transition: %b. Alarm specific problem: %s.", SMTOtuAlarmSeverity::hasSeverityTransition( $otuAlarm->getOtuSeverity() ), $otuAlarm->getSpecificProblemCode()), SMTLogger::INFO );
     
@@ -443,7 +444,7 @@ class SMTAlarmFactory
 			$alarmEvent = new SMTSystemAlarmEventDto();
 			$alarmEvent->setAlarmId( $alarm->getId() );
 			$alarmEvent->setSeverity( $severity );
-			$alarmEvent->setTime( $otuAlarm->getGenerationDateUTC( $dbConnection ) );
+			$alarmEvent->setTime( $otuAlarm->getGenerationDateUTC( $context ) );
 
 			//attach the event to the alarm
 			//last event is always the real status of the system alarm (no persistent failure....)
