@@ -50,8 +50,8 @@ class SMTAutotest extends SMTServiceHelper
         //create autotest dto from otu autotest dto:
         $autotestDto = new SMTAutotestDto();
         $autotestDto->setDurationSec( $autotestOtuDto->getDurationSec() );
-        $autotestDto->setSequencerLastRunTimestamp( $autotestOtuDto->getSequencerLastRunDateSecUTC( $dbConnection ) );
-        $autotestDto->setStartTimestamp( $autotestOtuDto->getEndDateUTC( $dbConnection ) - $autotestOtuDto->getDurationSec() );
+        $autotestDto->setSequencerLastRunTimestamp( $autotestOtuDto->getSequencerLastRunDateSec() );
+        $autotestDto->setStartTimestamp( $autotestOtuDto->getEndDate() - $autotestOtuDto->getDurationSec() );
         $autotestDto->setStatusOK( $autotestOtuDto->isAutotestSuccessful() );
         $autotestDto->setAutotestSummaryFileName( $autotestOtuDto->getAutotestSummaryFileName() );
         $autotestDto->save($dbConnection);
