@@ -18,6 +18,7 @@ use app\parser\SMTOtuSocket;
 
 use app\parser\SMTOtuApi;
 use app\services\setup\SMTRotauDto;
+use app\util\SMTLogger;
 
 /**
  *
@@ -53,11 +54,18 @@ class SMTRotauSwitchDet extends SMTMacroSwitch
      */
     protected function retrieveGlobal()
     {
-    	$result = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_desc, $this->macroSwitchId, parent::GLOB ) );
-    	list( $device, $code, $rotauIp ) = explode(',', $result);
-    	$this->device = trim($device);
-    	$this->rotauIp = trim($rotauIp);
-        $this->setSwitchDecoder( parent::GLOB, $code );
+        try 
+        {            
+    	   $result = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_desc, $this->macroSwitchId, parent::GLOB ) );
+    	   list( $device, $code, $rotauIp ) = explode(',', $result);
+    	   $this->device = trim($device);
+    	   $this->rotauIp = trim($rotauIp);
+           $this->setSwitchDecoder( parent::GLOB, $code );
+        } 
+        catch (\Exception $e) 
+        {
+           SMTLogger::getInstance()->traceException($e);
+        }        
     }
     
     /**
@@ -73,7 +81,14 @@ class SMTRotauSwitchDet extends SMTMacroSwitch
      */
     protected function retrieveSN()
     {
-    	$this->serialNumber= $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_get_rotau_sn_det, $this->macroSwitchId ) );
+        try 
+        {
+    	   $this->serialNumber= $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_get_rotau_sn_det, $this->macroSwitchId ) );
+        } 
+        catch (\Exception $e) 
+        {
+           SMTLogger::getInstance()->traceException($e);
+        }
     }
 
     /**
@@ -81,7 +96,7 @@ class SMTRotauSwitchDet extends SMTMacroSwitch
      * @param $detected boolean Whether the switch is detected or retrieved from configuration
      *
      */
-    protected function buildSwitchDto()
+    protected function buildSwitchDto($detected)
     {    	
     	//if global switch decoder exists (case of detection), set it in the dto.
     	$decoder = $this->getSwitchDecoder( self::GLOB );
