@@ -198,7 +198,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     {
     	//by default power is ON (power management not supported by OTU8kv2 old B43)
     	$powerOn = TRUE;
-    	$queryPower = SMTOtuType::isCOtu();
+    	$queryPower = SMTOtuType::isCOtu() || SMTOtuType::isOTH() || SMTOtuType::isFTH7K();
     	
     	if ( SMTOtuType::isOtu8KV2() )
     	{
@@ -429,7 +429,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
      */
     function checkDtssSwitch()
     {
-        if ( SMTOtuType::isOtu8KV2() || SMTOtuType::isMTS8KV2() )
+        if ( SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() )
         {
             try
             {
@@ -523,7 +523,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     static function isDtssSwitchInCalibOrInDet(SMTOtuSocket $socket)
     {
         $DtssSwitch = FALSE;
-        if ( SMTOtuType::isOtu8KV2() || SMTOtuType::isMTS8KV2() )
+        if ( SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() )
         {
         	try
         	{
@@ -615,6 +615,28 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     	return $hasJdsuSwitch;
     }
     
+    function hasUOSDetected()
+    {
+        $hasUOSSwitch = FALSE;
+        try
+        {
+            if ($this->switchDetect!= NULL)
+            {
+                $hasUOSSwitch= $this->switchDetect->hasUOS();
+            }
+            else
+            {
+                $macroSwitchDet = new SMTMacroSwitchDet($this->getContext()->getOtuSocket());
+                $hasUOSSwitch= $macroSwitchDet->hasUOS();
+            }
+        }
+        catch ( \Exception $e )
+        {
+            //no log : can fail if no switch is set in the OTU
+            //SMTLogger::getInstance()->traceException($e);
+        }
+        return $hasUOSSwitch;
+    }
     
     function hasMolexOSU()
     {
@@ -675,11 +697,45 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     	return $hasJdsuSwitch;
     }
     
+    function hasUOS()
+    {
+        $hasUOSSwitch = FALSE;
+        try
+        {
+            if ( ($this->switchConfig != NULL) || ($this->switchDetect!= NULL) )
+            {
+                $hasUOSSwitch= ( ($this->switchConfig != NULL) && ($this->switchConfig->hasUOS()) ) ||
+                ( ($this->switchDetect!= NULL) && ($this->switchDetect->hasUOS()) );
+            }
+            else
+            {
+                $macroSwitchConf = new SMTMacroSwitchConf($this->getContext()->getOtuSocket());
+                $hasUOSSwitch= $macroSwitchConf->hasUOS();
+                if ( !$hasUOSSwitch)
+                {
+                    $macroSwitchDet = new SMTMacroSwitchDet($this->getContext()->getOtuSocket());
+                    $hasUOSSwitch= $macroSwitchDet->hasUOS();
+                }
+            }
+        }
+        catch ( \Exception $e )
+        {
+            //no log : can fail if no switch is set in the OTU
+            //SMTLogger::getInstance()->traceException($e);
+        }
+        return $hasUOSSwitch;
+    }
+    
     function isMolexSwitchPossible()
     {
     	return strcasecmp( 'TRUE', $this->sendReceive( SMTOtuApi::CMD_get_switch_molex_available) ) == 0;
     }
     
+    function isUosSwitchPossible()
+    {
+        return strcasecmp( 'TRUE', $this->sendReceive( SMTOtuApi::CMD_get_switch_uos_available) ) == 0;
+    }
+    
     function isModuleCompatibleWithSwitch()
     {
     	return strcasecmp( 'TRUE', $this->sendReceive( SMTOtuApi::CMD_check_module_compatibility_with_switch ) ) == 0;
@@ -801,7 +857,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     {
         if ( $forceDetection )
             {
-            $this->switchDifference = $this->getContext()->getOtuSocket()->sendReceive( sprintf( SMTOtuApi::CMD_compare_switches, self::MACRO_SWITCH_ID ), SMTOtuSocket::DEFAULT_SLEEP, 90, TRUE );
+            $this->switchDifference = $this->getContext()->getOtuSocket()->sendReceive( sprintf( SMTOtuApi::CMD_compare_switches, self::MACRO_SWITCH_ID ), SMTOtuSocket::DEFAULT_SLEEP, 120, TRUE );
 //     	    $this->switchDifference = $this->sendReceive( sprintf( SMTOtuApi::CMD_compare_switches, self::MACRO_SWITCH_ID ) );
             }
         else
