@@ -33,7 +33,7 @@ function init( SMTContext $context )
 	if ( $session->getUser() == null )
 	{
 		$success = FALSE;
-		$context->closeSession();
+		$context->closeSession("upload Not logged in");
 		SMTLogger::getInstance()->trace('Not logged in! ', SMTLogger::ERROR);
 	}
 	else if ( $context->getHttpRequest()->checkReferer() && $context->getHttpRequest()->checkToken( "" ) )
@@ -172,7 +172,7 @@ function checkBackup($filename, SMTContext $context)
 	if ( checkBackupExtension($filename) )
 	{
 		//remove old backups
-		array_map('unlink', glob( SMTOtuBackupRestore::OTU_BACKUP_DIR.SMTOtuBackupRestore::OTU_BACKUP_NAME_PREFIX."*".SMTOtuBackupRestore::OTU_BACKUP_NAME_SUFFIX ) );
+	    array_map('unlink', glob( SMTOtuBackupRestore::getBackupDir().SMTOtuBackupRestore::OTU_BACKUP_NAME_PREFIX."*".SMTOtuBackupRestore::OTU_BACKUP_NAME_SUFFIX ) );
 		
 		//check backup integrity
 		$backupHelper = new SMTOtuBackupRestore();
@@ -278,6 +278,58 @@ function check5kRelease($filename, SMTContext $context)
 	}
 	return $checked;
 }
+
+function checkfth9000ReleaseExtension($filename)
+{
+    return ( strpos($filename, 'fth-9000') !== FALSE) && (strcasecmp(pathinfo($filename, PATHINFO_EXTENSION), 'tar' ) == 0 );
+}
+function checkfth9000Release($filename, SMTContext $context)
+{
+    $checked = FALSE;
+    if ( checkfth9000ReleaseExtension($filename) )
+    {
+        try
+        {
+            $checked = SMTUpgrade::checkUpgradeArchive($_FILES['datafile']['tmp_name'], $context);
+        }
+        catch(\Exception $e)
+        {
+            unlink($_FILES['datafile']['tmp_name']);
+            SMTLogger::getInstance()->trace('Invalid FTH release file content : '.$filename, SMTLogger::ERROR);
+        }
+    }
+    else
+    {
+        unlink($_FILES['datafile']['tmp_name']);
+    }
+    return $checked;
+}
+function checkfth7000ReleaseExtension($filename)
+{
+    return ( strpos($filename, 'fth-7000') !== FALSE) && (strcasecmp(pathinfo($filename, PATHINFO_EXTENSION), 'tar' ) == 0 );
+}
+function checkfth7000Release($filename, SMTContext $context)
+{
+    $checked = FALSE;
+    if ( checkfth7000ReleaseExtension($filename) )
+    {
+        try
+        {
+            $checked = SMTUpgrade::checkUpgradeArchive($_FILES['datafile']['tmp_name'], $context);
+        }
+        catch(\Exception $e)
+        {
+            unlink($_FILES['datafile']['tmp_name']);
+            SMTLogger::getInstance()->trace('Invalid FTH release file content : '.$filename, SMTLogger::ERROR);
+        }
+    }
+    else
+    {
+        unlink($_FILES['datafile']['tmp_name']);
+    }
+    return $checked;
+}
+
 /////////////////////////////////////////////////////////////////////////////////////////
 //
 // Certificates check
