@@ -8,6 +8,8 @@ use app\services\maintenance\SMTUploadStatusDto;
 use app\serviceshelper\maintenance\SMTUpgrade;
 use app\util\upload\SMTUploadStatus;
 
+
+
 /**
  * Begining of upload script
  * 
@@ -19,7 +21,7 @@ $noUploadRunning = SMTUploadStatus::checkNoUploadRunning();
 
 if ( $noUploadRunning == TRUE )
 {
-    $uploadStatus = upload_file( SMTUpgrade::OTU_PATCH_CURRENT_DIR );    
+	$uploadStatus = upload_file( SMTUpgrade::OTU_PATCH_CURRENT_DIR, 'checkPatch');    
 }
 else
 {
@@ -27,6 +29,9 @@ else
     $uploadStatus->setProgress( SMTUploadStatusDto::NO_UPLOAD );
     $uploadStatus->setUploadErrorStatus( SMTUploadStatusDto::UPLOAD_ALREADY_RUNNING );
     SMTLogger::getInstance()->trace("Upload already running...", SMTLogger::ERROR);
+    
+    // add error code 401 in case of upload failure
+    @header('Cache-Control: no-cache, must-revalidate', true, 401 ); 
 }
 
 $response = buildJsonResponse( $uploadStatus );
