@@ -231,9 +231,9 @@ class SMTUploadStatus
     {
     	if ( PHP_MAJOR_VERSION >= 6 )
     	{
-    		$key = ini_get("session.upload_progress.prefix").self::OTU_UPLOAD_PROGRESS_KEY;//$_POST[ini_get("session.upload_progress.name")];
+    	    $sessionKey = ini_get("session.upload_progress.prefix").self::OTU_UPLOAD_PROGRESS_KEY;//$_POST[ini_get("session.upload_progress.name")];
     		
-    		SMTLogger::getInstance()->trace("Get upload info with key ".$key, SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);
+    	    SMTLogger::getInstance()->trace("Get upload info with key ".$sessionKey, SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);
     		
     		$uploadInfo = (isset($_SESSION[$sessionKey])) ? $_SESSION[$sessionKey] : NULL;
     		if ( $uploadInfo != NULL )
