@@ -32,7 +32,7 @@ class SMTFileDownloadPage implements SMTIPage
 	
 	private $FILES_ALLOWED_FOR_DOWNLOAD = array('gz','tar.gz','log','tar','kml','kmz');
 	//kml alarm/autotest/backup/snapshot and mib/kml/
-	private $DIRECTORIES_ALLOWED_FOR_DOWNLOAD = array(SMTSessionDirectoryUtil::SMART_OTU_TEMP_DIR,'/acterna/user//harddisk/otu/autotest/','/user//harddisk/otu/autotest/','/user//harddisk/','/acterna/user//harddisk/',SMTOtuDebug::SNAPSHOT_DIR,SMTGpsRoute::GPS_ROUTE_DIR);
+	private $DIRECTORIES_ALLOWED_FOR_DOWNLOAD = array(SMTSessionDirectoryUtil::SMART_OTU_TEMP_DIR,'/user//harddisk/otu/autotest/','/user/harddisk/','/user//harddisk/',SMTGpsRoute::GPS_ROUTE_DIR);
 	
 	/**
 	 * Construct the builder to download the given file.
