@@ -24,12 +24,14 @@ usage() {
   echo "	                                      --tar is the tarball of the /otu/release/current with latest modification time"
   exit -1
   }
+
 PRG_NAME=`basename $0`
 #echo "script $0 $@"
 # Attention: test de l'absence de parametre a n'executer que lors du premier appel; pas a la deuxieme invocation par nohup ou l'on n'a plus de parametre (perdus dans le parsing "parse params for this script")
 if [ -z "${DETACHED}" ] ; then
    [ $# -eq 0 ] && usage
 fi
+
 # ce script ne fonctionne pas correctement: retourne toujours 0 et donc, n'appelle jamais: usage(). Non corrige, car pourrait etre bloquant si l'on ajoutait un parametre et que l'on oubliait de la rajouter ici.
 set -- `getopt -n$0 -u --longoptions="tar: index: pmulti fromscratch target: noreboot nodet help nomd5 short upgradeversion" "h" "$@"` || usage
 
@@ -37,7 +39,7 @@ set -- `getopt -n$0 -u --longoptions="tar: index: pmulti fromscratch target: nor
 while [ $# -gt 0 ]
 do
     case "$1" in
-       --tar)   		export TARBALL=$2;shift;;
+       --tar)   		export TARBALL="$2";shift;;
        --index)   		export INDEX=$2;shift;;
        --target) 		export TARGET=$(echo $2 | tr '[:upper:]' '[:lower:]') ;shift;;
        --fromscratch)   export FROMSCRATCH="--fromscratch";;
@@ -50,7 +52,7 @@ do
        --nodet)     	NOTDETACHED=1;;
        -h)        	    usage;;
        --) 		        shift;break;;
-       -*)        	    usage;;       
+       -*)        	    usage;;
        *)         	    usage;;
     esac
     shift
@@ -58,15 +60,15 @@ done
 
 # Display the version if asked and exit without doing anything else
 if [ ! -z "${SHOW_VERSION}" ] ; then
-     VERSION=$(tar --test-label -f ${TARBALL})
+     VERSION=$(tar --test-label -f "${TARBALL}")
      echo ${VERSION} | cut -f 2 -d ':' | tr -d ' '
      exit 0
 fi
 
 if [ ! -z ${USE_DEFAULT} ] ; then
 	# if the tarball hasn't been specified then use the tarball located in /otu/release/current with the mostrecent modification time
-	[ -z ${TARBALL} ] && TARBALL=`ls -t /otu/release/current/*.tar* | head -n 1` && echo "no tarball specified. using default tarball : ${TARBALL}"
-	TARGET=normal 
+	[ -z "${TARBALL}" ] && TARBALL=`ls -t /otu/release/current/*.tar* | head -n 1` && echo "no tarball specified. using default tarball : ${TARBALL}"
+	TARGET=normal
 	INDEX=normal
 	NOMD5=1
 fi
@@ -78,13 +80,13 @@ fi
 # echo other arguments param [nb = $#] $*
 
 #check the parameters
-if [ -z ${TARBALL} ] ; then
+if [ -z "${TARBALL}" ] ; then
   echo "missing the installation Tar file in command line"
   usage
   exit -1
 fi
 
-if [ ! -f ${TARBALL} ] ; then
+if [ ! -f "${TARBALL}" ] ; then
   echo "${TARBALL} is not a valid file"
   usage
   exit -1
@@ -94,8 +96,8 @@ fi
 if [ -z "${DETACHED}" ] ; then
    export DETACHED=1
    export LOGFILE=/var/log/otu_upgrade_$(date +%y-%m-%d-%H.%M.%S)
-    
-   #detached case   
+
+   #detached case
    if [ -z "$NOTDETACHED" ] ; then
       if [ ! -z "${DEBUG}" ] ; then
          # $* ne sert a rien car les parametres sont perdus lors du premier parsing dans "parse params for this script"
@@ -107,10 +109,10 @@ if [ -z "${DETACHED}" ] ; then
    # Not detached case
    else
       # $* ne sert a rien car les parametres sont perdus lors du premier parsing dans "parse params for this script"
-      nohup $0 $* 
-      cat ${LOGFILE} 
+      nohup $0 $*
+      cat ${LOGFILE}
    fi
-   sleep 1  
+   sleep 1
    exit
 fi
 
@@ -178,30 +180,67 @@ fi
 [ ! -z "${PMULTI}" ] && [ "${CURRENT_FS}" == "rescue" ] && { echo "can't do an installation from pmulti from the rescue filesystem!" ; exit -1 ; }
 [ ! -z "${PMULTI}" ] && [ "rescue" == "${TARGET}" ] && { echo "can't do an installation of the rescue filesystem from pmulti!" ; exit -1 ; }
 
+# function do_reboot() {
+#   if [ -z "$NOREBOOT" ] ; then
+#     REBOOT_DELAY=60
+#     echo "no --noreboot option detected. rebooting in $REBOOT_DELAY secs ..."
+#     sync
+#     shutdown -r +1
+#   fi
+# }
+
 function do_reboot() {
-if [ -z "$NOREBOOT" ] ; then
-   REBOOT_DELAY=15
-   echo "no --noreboot option detected. rebooting in $REBOOT_DELAY secs ..."
-   sleep ${REBOOT_DELAY}
-   sync
-   reboot
-fi
+  if [ -z "$NOREBOOT" ] ; then
+    EXEC_REBOOT="/root/wait_reboot.sh"
+    REBOOT_DELAY=15
+    echo "no --noreboot option detected. rebooting in $REBOOT_DELAY secs ..."
+    sync
+    echo "#!/bin/bash
+    sleep $REBOOT_DELAY
+    reboot
+    " > $EXEC_REBOOT
+    chmod +x $EXEC_REBOOT
+    nohup $EXEC_REBOOT </dev/null >/tmp/nohup.out 2>&1 &
+  fi
+}
+
+
+function restart_service() {
+  if $(readlink /sbin/init | grep -q systemd); then
+    systemctl restart "$1"
+  else
+    /etc/init.d/"$1" restart
+  fi
+}
+
+function stop_service() {
+  if $(readlink /sbin/init | grep -q systemd); then
+    systemctl stop "$1"
+  else
+    /etc/init.d/"$1" stop
+  fi
 }
 
 echo $(date) > ${STATUS_LOG_FILE}
 
-log_msg "installing : ${TARBALL}"
+log_msg "Installing : ${TARBALL}"
 
 #installing a new trap
 trap  "${TRAP_WITH_REBOOT}" EXIT
 
+if $(readlink /sbin/init | grep -q systemd); then
+    # arrêt des application (et du watchdog), nécessaire au bon fonctionnement du Manager ONMSi...
+    stop_service watchdog
+    stop_service isu_ona
+fi
+
 #untar the tarball
 log_msg "Uncompressing the tarball."
 if [ "$RET" == "0" ] ; then
-      echo extracting ${TARBALL} ...
+      echo "extracting ${TARBALL} ..."
       rm -rf ${INSTALLATION_TMP_FOLDER}
-      mkdir -p ${INSTALLATION_TMP_FOLDER} && tar xf ${TARBALL}  --no-same-owner --no-same-permissions -C ${INSTALLATION_TMP_FOLDER}
-      RET=$? ; 
+      mkdir -p ${INSTALLATION_TMP_FOLDER} && tar xf "${TARBALL}"  --no-same-owner --no-same-permissions -C ${INSTALLATION_TMP_FOLDER}
+      RET=$? ;
       [ "$RET" != "0" ] && log_msg "Error while extracting $TARBALL in ${INSTALLATION_TMP_FOLDER}"  || log_msg "done..."
       ! [ -e ${INSTALLATION_TMP_FOLDER}/release.xml ] && log_msg "Error no release.xml in tarball!" && RET=1
 fi
@@ -213,28 +252,38 @@ if [ "$RET" == "0" ] ; then
     rm -rf /acterna/storage/fo/configs/otdr/*.*
     rm -rf /acterna/storage/fo/results/otdr/*.*
 
-	# get back log from syslog to the log file
-	tail -n 0 -f /var/log/daemon.log &
+	# get back log from release-manager into this log file
+	if $(readlink /sbin/init | grep -q systemd); then
+	  journalctl -n 0 -b -u release-manager -f &
+	else
+	  tail -n 0 -f /var/log/daemon.log &
+	fi
 	LOG_REDIRECT=$!
 
 	# Check release-manager daemon is running
 	RELEASE_MANAGER_PID=$(pgrep release-manager)
-	[ -z ${RELEASE_MANAGER_PID} ] && /etc/init.d/release-manager restart && log_msg "Release-manager was not running! starting it"
+	[ -z ${RELEASE_MANAGER_PID} ] && restart_service release-manager && log_msg "Release-manager was not running! starting it"
 
-	# Launch client for release_manager : starting the operation but not doing it.
+	# Launch client for release_manager : starting the operation AND doing it
 	release-manager start_upgrade 0:${INSTALLATION_ROOT_FOLDER}/tmp/release.xml
 	if [ "$?"  != "0" ]; then
 		log_msg "Release-manager client has failed to start"
 		RET=1
 		kill ${LOG_REDIRECT}
 	else
-		sleep 1  		# lets the daemon start its job	
+		sleep 1  		# lets the daemon start its job
 	fi
 fi
 if [ "${RET}" == "0" ] ; then
     fw_setenv upgrade_pending yes
     # Do not sync when duplicating
-    /etc/init.d/otu_rfs_sync.sh stop
+    if $(readlink /sbin/init | grep -q systemd); then
+       stop_service otu-rfs-sync
+    else
+       stop_service otu_rfs_sync.sh
+    fi
+    /sbin/otu_rfs_duplicate.sh
+
 	# Wait for the upgrade to be completed
 	OPERATION_COMPLETED="NO"
 
@@ -278,6 +327,8 @@ fi
 rm -f ${INSTALLATION_ROOT_FOLDER}/current/duplication_status
 otu_confirm_start.sh
 
+[[ ${RET} -eq 0 ]] && /sbin/otu_rfs_duplicate.sh
+
 do_reboot
 
 echo "${RET}"
