@@ -9,6 +9,7 @@ LPORT=$1
 IP=$2
 DPORT=$3
 SSHPORT=$4
+ONMSI_LOCAL_HOST=$5
 TMP_SSH_RESULT="/tmp/ssh.result"
 TMP_SSH_PID="/tmp/ssh.pid"
 PRIVATE_KEY="/home/secuser/.ssh/otu_id_rsa_4096"
@@ -20,12 +21,12 @@ SSH_UP=0
 
 function usage ()
         {
-    echo "usage : tpz_ssh_up local_port ip_address distant_port"
+    echo "usage : tpz_ssh_up local_port ip_address distant_port ONMSI_LOCAL_HOST"
         }
 
 
 # check for parametres
-if [ $# != 4 ]
+if [ $# != 5 ]
 then
         usage
     exit 1
@@ -36,7 +37,7 @@ rm -f $TMP_SSH_RESULT
 rm -f $TMP_SSH_PID
 
 # lancement et detachement de ssh en mode tunnel, timeout a 15 secondes
-ssh -i $PRIVATE_KEY -p $SSHPORT -o ConnectTimeout=$TESTTIMEOUT -o StrictHostKeyChecking=no -L $LPORT:localhost:$DPORT secuser@$IP -N 2> $TMP_SSH_RESULT &
+ssh -i $PRIVATE_KEY -p $SSHPORT -o ConnectTimeout=$TESTTIMEOUT -o StrictHostKeyChecking=no -L $LPORT:$ONMSI_LOCAL_HOST:$DPORT secuser@$IP -N 2> $TMP_SSH_RESULT &
 
 # get PID as command returned value, and save to file
 PID=$!
