@@ -29,11 +29,76 @@ import distutils
 from distutils.msvccompiler import MSVCCompiler
 from distutils.unixccompiler import UnixCCompiler
 from distutils.cygwinccompiler import Mingw32CCompiler
-from distutils.sysconfig import customize_compiler
+from distutils.sysconfig import get_config_vars
+from distutils.sysconfig import customize_compiler as orig_customize_compiler
 
 from . import utils
 
 
+def customize_compiler(compiler):
+    """This is a version of distutils.sysconfig.customize_compiler, without
+    any macOS specific bits and which tries to avoid using any Python specific
+    defaults if alternatives through env vars are given.
+    """
+
+    # The original customize_compiler() in distutils calls into macOS setup
+    # code the first time it is called. This makes sure we run that setup
+    # code as well.
+    dummy = distutils.ccompiler.new_compiler()
+    orig_customize_compiler(dummy)
+
+    if compiler.compiler_type == "unix":
+        (cc, cxx, ldshared, shlib_suffix, ar, ar_flags) = \
+            get_config_vars('CC', 'CXX', 'LDSHARED', 'SHLIB_SUFFIX', 'AR', 'ARFLAGS')
+
+        if 'CC' in os.environ:
+            newcc = os.environ['CC']
+            if 'LDSHARED' not in os.environ and ldshared.startswith(cc):
+                ldshared = newcc + ldshared[len(cc):]
+            cc = newcc
+        if 'CXX' in os.environ:
+            cxx = os.environ['CXX']
+        if 'LDSHARED' in os.environ:
+            ldshared = os.environ['LDSHARED']
+        if 'CPP' in os.environ:
+            cpp = os.environ['CPP']
+        else:
+            cpp = cc + " -E"
+        if 'LDFLAGS' in os.environ:
+            ldshared = ldshared + ' ' + os.environ['LDFLAGS']
+        if 'CFLAGS' in os.environ:
+            cflags = os.environ['CFLAGS']
+            ldshared = ldshared + ' ' + os.environ['CFLAGS']
+        else:
+            cflags = ''
+        if 'CPPFLAGS' in os.environ:
+            cpp = cpp + ' ' + os.environ['CPPFLAGS']
+            cflags = cflags + ' ' + os.environ['CPPFLAGS']
+            ldshared = ldshared + ' ' + os.environ['CPPFLAGS']
+        if 'AR' in os.environ:
+            ar = os.environ['AR']
+        if 'ARFLAGS' in os.environ:
+            archiver = ar + ' ' + os.environ['ARFLAGS']
+        else:
+            archiver = ar + ' ' + ar_flags
+
+        cc_cmd = cc + ' ' + cflags
+        compiler.set_executables(
+            preprocessor=cpp,
+            compiler=cc_cmd,
+            compiler_so=cc_cmd,
+            compiler_cxx=cxx,
+            linker_so=ldshared,
+            linker_exe=cc,
+            archiver=archiver)
+
+        compiler.shared_lib_extension = shlib_suffix
+
+
+# Flags that retain macros in preprocessed output.
+FLAGS_RETAINING_MACROS = ['-g3', '-ggdb3', '-gstabs3', '-gcoff3', '-gxcoff3', '-gvms3']
+
+
 class CCompiler(object):
 
     compiler_cmd = ''
@@ -271,10 +336,6 @@ class CCompiler(object):
             args.append('dumpbin.exe')
             args.append('-symbols')
 
-            # Work around the attempt to resolve m.lib on Python 2.x
-            if sys.version_info.major < 3:
-                libraries[:] = [lib for lib in libraries if lib != 'm']
-
         # When we are not using Visual C++ (i.e. we are using GCC)...
         else:
             libtool = utils.get_libtool_command(options)
@@ -352,6 +413,15 @@ class CCompiler(object):
                 ", ".join(not_resolved))
         return shlibs
 
+    @property
+    def linker_cmd(self):
+        if self.check_is_msvc():
+            if not self.compiler.initialized:
+                self.compiler.initialize()
+            return [self.compiler.linker]
+        else:
+            return self.compiler.linker_exe
+
     def check_is_msvc(self):
         return isinstance(self.compiler, MSVCCompiler)
 
@@ -380,6 +450,6 @@ class CCompiler(object):
             else:
                 # We expect the preprocessor to remove macros. If debugging is turned
                 # up high enough that won't happen, so don't add those flags. Bug #720504
-                if option not in ['-g3', '-ggdb3', '-gstabs3', '-gcoff3', '-gxcoff3', '-gvms3']:
+                if option not in FLAGS_RETAINING_MACROS:
                     other_options.append(option)
         return (includes, macros, other_options)
