@@ -1,8 +1,7 @@
 # coding: utf-8 
-# coding: utf-8 
 # machine: eotdrv2
 
-ver='03-08-2021'
+ver='25-02-2022'
 repertoire=r"/sys/platform/"
 freqADC=160e6
 
@@ -804,15 +803,15 @@ def recordXADC(channels,duree=None,avgnb=1):
             
     # ******************ancienne fonction*******************************
     #~ # enregistrement dans des listes
-    open('/tmp/record_running', 'a').close()
+    open(rep+'record_running', 'a').close()
     if duree==None:
-        print("%d points par sec (effacer le fichier /tmp/record_running pour stopper)"%(nbParSec))
+        print("%d points par sec (effacer le fichier %srecord_running pour stopper)"%(nbParSec,rep))
     else:
         print("%d points par sec pendant %ds = %d points"%(nbParSec,duree,duree*nbParSec))
     debut=debut0=time()
     i=0
     values={}
-    while ((duree==None and os.path.isfile('/tmp/record_running')) or (duree!=None and time()-debut0<duree)):
+    while ((duree==None and os.path.isfile(rep+'record_running')) or (duree!=None and time()-debut0<duree)):
     #~ for i in range(1,duree*nbParSec+1):
         i+=1
         x+=str(time()-debut0)+','
@@ -868,9 +867,10 @@ def recordXADC(channels,duree=None,avgnb=1):
 
             
 def stopRecord():
+    rep="/var/lib/ftp/"
     from os import remove
     try:
-        remove('/tmp/record_running')
+        remove(rep+'record_running')
         print('XADC record stopped')
     except:
         print('was not recording')
@@ -907,21 +907,18 @@ def dumpListinFile(liste, filename="/var/lib/ftp/xadc.csv"):
     print("%s written"%filename)
 
 #~ @DIAG("Test APD presence",depends=["analog_powersupply",  "adc", "dac_ht"])
-def t_apd(head='',points=2000,avg=5000,augmentation=1.5,gain='GAIN_4K64'):
+def t_apd(start=35,stop=55,points=2000,avg=5000,seuil_bruit=1.5,seuil_niveau=2,gain='GAIN_4K64'):
     '''
-    Command must be: t_apd <head> where <head> is 1625DFB|1650FP
+    t_apd(start=35,stop=55,points=2000,avg=5000,seuil_bruit=1.5,seuil_niveau=2,gain='GAIN_4K64'):
+    
+    seuil=2.51 pour 5*log10(2.51)=2dB
     '''
-    if head.upper() not in ("1625DFB","1650FP"):
-        print_error("Command must be: t_apd(head,avg=500,augmentation=1.5)")
-        print_error("<head> is 1625DFB|1650FP")
-        return(-1)
-
-    if (head.upper()=="1625DFB"):
-        ht = int(CONST("vapd.1625dfb.min",60)) #60
-        ht_max = int(CONST("vapd.1625dfb.max",90))#95
-    else:
-        ht = int(CONST("vapd.1650FP.min",35))
-        ht_max = int(CONST("vapd.1650FP.max",60))
+    rep="/var/lib/ftp/"
+    ht=start
+    ht_max=stop
+    l_vapd=[]
+    l_noise=[]
+    l_avg=[]
 
     noise_decol = False
     apd_detected = False
@@ -942,10 +939,8 @@ def t_apd(head='',points=2000,avg=5000,augmentation=1.5,gain='GAIN_4K64'):
     otdr.StartAndPoolAcq(False)
     otdr.AvgAcq(points)
     initial_noise = (( otdr.max_acq - otdr.min_acq) / otdr.avg ) * 100
-    initial_offset = otdr.avg
-    target_noise = initial_noise*augmentation
-    target_offset = initial_offset*augmentation
-    print_info("* Initial Noise = %.3e => Target Noise = %.3e (Avg=%d)" %(initial_noise,target_noise,otdr.avg))
+    initial_offset = otdr.avg/avg-0 #otdr.avg-2048*avg 
+    print_info("* Initial Noise = %.3e ; Initial Offset = %d)" %(initial_noise,initial_offset)) 
     dumpAcqFile(points*5,skip=300,)
 
     otdr.ConfigAcqBIST(points,avg,0, 0 )
@@ -964,25 +959,48 @@ def t_apd(head='',points=2000,avg=5000,augmentation=1.5,gain='GAIN_4K64'):
         #~ noise = otdr.getBufferNoise(avg)
         otdr.AvgAcq(points)
         noise = (( otdr.max_acq - otdr.min_acq) / otdr.avg ) * 100
-        print("# HT = %5.2f   Vapd=%5.2f => Noise *%.2f (Avg=%d)" %(ht,sysfs_read("/sys/platform/adc_vcc_apd/value"),noise/initial_noise,otdr.avg),end='\r',flush=True)
-        if not apd_detected :#la 1ère fois
-            if (noise > target_noise or otdr.avg>target_offset):
+        offset = otdr.avg/avg-0 #otdr.avg-2048*avg 
+        delta_noise = noise/initial_noise
+        delta_offset = offset-initial_offset
+        
+        l_vapd.append(str(ht))
+        l_noise.append(str(noise))
+        l_avg.append(str(offset)) 
+        
+        print("# HT = %5.2f   Vapd=%5.2f => Noise *%.2f ; Offset +%.3f" %(ht,sysfs_read("/sys/platform/adc_vcc_apd/value"),delta_noise,delta_offset),end='\r',flush=True) 
+        if (delta_noise > seuil_bruit or delta_offset > seuil_niveau):
+            if not apd_detected :#la 1ère fois
                 apd_detected = True
                 val_detected=ht-inc_ht
                 print_info("\n# APD detected")
-                #~ inc_ht = -0.1# on redescend doucement
                 ht -= inc_ht #retour au point precedent
+                setVAPD(ht)
+                sleep(200e-3)
                 inc_ht = 0.1# on monte doucement
                 dumpAcqFile(2000,skip=300)
-        else:#recherche fine
-            #~ if (noise < target_noise):
-            if (noise > target_noise or otdr.avg>target_offset):
+            else:#recherche fine
                 noise_decol = True
                 sleep(0.5) #temps de stabilisation mesure ADC
-                print_info("# DAC_APD=%.2fV   ADC_Vapd=%5.2fV"%(ht,sysfs_read("/sys/platform/adc_vcc_apd/value")))
+                print_info("\n# DAC_APD=%.2fV   ADC_Vapd=%5.2fV for Tmod=%.1f°C              "%(ht,sysfs_read("/sys/platform/adc_vcc_apd/value"),XADC('adc_temp_ana',None)))
                 setVAPD(ht-2)
     otdr.enableAPD(False)
     dumpAcqFile(2000,skip=300)
+    
+    #ecriture dans le fichiers
+    file=rep+'vdec_noise'
+    with open(file,'w') as f: 
+        f.write(','.join(l_vapd))
+        f.write('\n')
+        f.write(','.join(l_noise))
+        print("\r datas recorded %s"%file)    
+
+    file=rep+'vdec_avg'
+    with open(file,'w') as f: 
+        f.write(','.join(l_vapd))
+        f.write('\n')
+        f.write(','.join(l_avg))
+        print("\r datas recorded %s"%file)    
+        
     if not apd_detected:
         print_error("\n# APD not detected !")
         setVAPD(20)
@@ -1147,12 +1165,11 @@ def PID_enable(enable=True,verbose=True):
 def PID_set(Kp=None,KpDecal=None,Ki=None,KiDecal=None,Kd=None,KdDecal=None):
     otdr=Otdr_Acq()
     if Kp==None and Ki==None and Kd==None and KpDecal==None and KiDecal==None and KdDecal==None:
-        Kp=512
-        Ki=5
-        Kd=2048
-        KpDecal=10
-        KiDecal=10
-        KdDecal=10
+        print('exemple pour EOTDR2-L-A1:')
+        print('PID_set(Kp=1792,Ki=1,Kd=61440,KpDecal=8,KiDecal=8,KdDecal=8)\n')
+        print('exemple pour EOTDR2-1625-M:')
+        print('PID_set(Kp=512,Ki=5,Kd=2048,KpDecal=10,KiDecal=10,KdDecal=10)\n')
+        return
     if Kp!=None:
         otdr.utsbdt.rw_register(UtsBdt.WRITE, REG_PID_Kp, 0x0000FFFF, Kp )
     if Ki!=None:
