@@ -1,19 +1,19 @@
 
 from viavi.qrcodegen.cdm_proxy import CdmProxy
-from .olts_builder import VzOltsBuilder, VzJsonLite
-from .otdr_builder import VzOtdrBuilder
+from .olts_builder import OltsBuilder, JsonLite
+from .otdr_builder import OtdrBuilder
 
 
-class VzQrCdmFactory:
+class QrCdmFactory:
     def __init__(self, cdm: CdmProxy):
-        self._cdm = cdm
+        self._cdm: CdmProxy = cdm
 
-    def create_json_lite(self) -> VzJsonLite:
+    def create_json_lite(self) -> JsonLite:
         if self._cdm.test_type == "bidirIlOrl":
-            builder = VzOltsBuilder(self._cdm)
+            builder = OltsBuilder(self._cdm)
 
         elif self._cdm.test_type == "OTDR":
-            builder = VzOtdrBuilder(self._cdm)
+            builder = OtdrBuilder(self._cdm)
 
         else:
             raise TypeError
