@@ -3,8 +3,8 @@ from viavi.diag import *  # needed to define RESOURCE name and sysfs_* functions
 # from time import time, localtime, sleep            # needed for sleep()
 from time import sleep
 import time
-from jdsu.mts.uts_bdt import UtsBdt  # seels jdsu/mts/uts_bdt.py or /usr/lib/python3.5/jdsu/mts/uts_bdt.py
-from jdsu.mts.evdev import InputDevice
+from viavi.mts.uts_bdt import UtsBdt  # seels jdsu/mts/uts_bdt.py or /usr/lib/python3.5/jdsu/mts/uts_bdt.py
+from viavi.mts.evdev import InputDevice
 import select
 import os
 import os.path
@@ -12,7 +12,7 @@ import subprocess
 import struct  # to use unpack method
 import hashlib
 from .eotdrv2_regs import *  # Needed for REG_DAC_VCC_APD definition
-from jdsu.mts.pca9535 import PCA9535  # see /usr/lib/python2.7/jdsu/mts/pca9535.py
+from viavi.mts.pca9535 import PCA9535  # see /usr/lib/python2.7/jdsu/mts/pca9535.py
 import traceback
 import smbus
 import serial
